@@ -2,7 +2,7 @@
  *  Hamlib CI-V backend - description of IC-736 and variations
  *  Copyright (c) 2000-2003 by Stephane Fillod
  *
- *	$Id: ic736.c,v 1.2 2003/04/06 18:40:35 fillods Exp $
+ *	$Id: ic736.c,v 1.6 2008/10/26 13:45:21 y32kn Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -24,6 +24,8 @@
 #include "config.h"
 #endif
 
+#include <stdlib.h>
+
 #include <hamlib/rig.h>
 #include <bandplan.h>
 #include "icom.h"
@@ -56,17 +58,16 @@
 static const struct icom_priv_caps ic736_priv_caps = { 
 		0x40,	/* default address */
 		0,		/* 731 mode */
-		ic737_ts_sc_list,
-		IC736_STR_CAL
+		ic737_ts_sc_list
 };
 
 const struct rig_caps ic736_caps = {
 .rig_model =  RIG_MODEL_IC736,
 .model_name = "IC-736", 
 .mfg_name =  "Icom", 
-.version =  "0.2", 
+.version =  BACKEND_VER, 
 .copyright =  "LGPL",
-.status =  RIG_STATUS_NEW,
+.status =  RIG_STATUS_UNTESTED,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
 .ptt_type =  RIG_PTT_NONE,
 .dcd_type =  RIG_DCD_NONE,
