@@ -2,7 +2,7 @@
  *  Hamlib CI-V backend - description of IC-7800 and variations
  *  Copyright (c) 2004 by Stephane Fillod
  *
- *	$Id: ic7800.c,v 1.4 2006/11/07 12:21:39 n0nb Exp $
+ *	$Id: ic7800.c,v 1.5 2008/10/26 13:45:21 y32kn Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -85,7 +85,7 @@ const struct rig_caps ic7800_caps = {
 .mfg_name =  "Icom", 
 .version =  BACKEND_VER, 
 .copyright =  "LGPL",
-.status =  RIG_STATUS_NEW,
+.status =  RIG_STATUS_UNTESTED,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
 .ptt_type =  RIG_PTT_RIG,
 .dcd_type =  RIG_DCD_RIG,
