@@ -1,8 +1,9 @@
 /*
  *  Hamlib Interface - API header
- *  Copyright (c) 2000-2008 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2003 by Frank Singleton
+ *  Copyright (c) 2000-2009 by Stephane Fillod
  *
- *	$Id: rig.h,v 1.130 2008/11/01 20:35:16 fillods Exp $
+ *	$Id: rig.h,v 1.141 2009/02/20 14:14:30 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -77,7 +78,9 @@ extern HAMLIB_EXPORT_VAR(const char) hamlib_copyright[];
 
 /**
  * \brief Hamlib error codes
- * Error codes that can be returned by the Hamlib functions
+ * Error code definition that can be returned by the Hamlib functions.
+ * Unless stated otherwise, Hamlib functions return the negative value
+ * of rig_errcode_e definitions in case of error, or 0 when successful.
  */
 enum rig_errcode_e {
 	RIG_OK=0,		/*!< No error, operation completed sucessfully */
@@ -238,7 +241,7 @@ enum rig_status_e {
   RIG_STATUS_UNTESTED,		/*!< Written from available specs, rig unavailable for test, feedback wanted! */
   RIG_STATUS_BETA,		/*!< Beta quality */
   RIG_STATUS_STABLE,		/*!< Stable */
-  RIG_STATUS_BUGGY,		/*!< Was stable, but something broke it! */
+  RIG_STATUS_BUGGY		/*!< Was stable, but something broke it! */
 /*  RIG_STATUS_NEW	*	*!< Initial release of code 
  *  				!! Use of RIG_STATUS_NEW is deprecated. Do not use it anymore */
 };
@@ -507,7 +510,8 @@ enum rig_conf_e {
 	RIG_CONF_STRING,	/*!<	String type */
 	RIG_CONF_COMBO,		/*!<	Combo type */
 	RIG_CONF_NUMERIC,	/*!<	Numeric type integer or real */
-	RIG_CONF_CHECKBUTTON	/*!<	on/off type */
+	RIG_CONF_CHECKBUTTON,	/*!<	on/off type */
+	RIG_CONF_BUTTON		/*!<    Button type */
 };
 
 #define RIG_COMBO_MAX	8
@@ -560,6 +564,7 @@ typedef int ant_t;
 #define RIG_ANT_2	RIG_ANT_N(1)
 #define RIG_ANT_3	RIG_ANT_N(2)
 #define RIG_ANT_4	RIG_ANT_N(3)
+#define RIG_ANT_5	RIG_ANT_N(4)
 
 /**
  * \brief AGC delay settings
@@ -571,7 +576,8 @@ enum agc_level_e {
 	RIG_AGC_FAST,
 	RIG_AGC_SLOW,
 	RIG_AGC_USER,		/*!< user selectable */
-	RIG_AGC_MEDIUM
+	RIG_AGC_MEDIUM,
+	RIG_AGC_AUTO
 };
 
 /**
@@ -584,7 +590,8 @@ enum meter_level_e {
   RIG_METER_ALC =	(1<<2),		/*< ALC */
   RIG_METER_IC =	(1<<3),		/*< IC */
   RIG_METER_DB =	(1<<4),		/*< DB */
-  RIG_METER_PO =	(1<<5)		/*< Power Out */
+  RIG_METER_PO =	(1<<5),		/*< Power Out */
+  RIG_METER_VDD =	(1<<6)		/*< Final Amp Voltage */
 };
 
 /**
@@ -635,7 +642,7 @@ enum rig_level_e {
 	RIG_LEVEL_ANTIVOX =	(1<<22),/*!< \c ANTIVOX -- anti-VOX level, arg float [0.0 ... 1.0] */
 	RIG_LEVEL_SLOPE_LOW = (1<<23),/*!< \c SLOPE_LOW -- Slope tune, low frequency cut, */
 	RIG_LEVEL_SLOPE_HIGH = (1<<24),/*!< \c SLOPE_HIGH -- Slope tune, high frequency cut, */
-	//RIG_LEVEL_LINEOUT =	(1<<23),/*!< Lineout Volume, arg float [0.0 ... 1.0] */
+	RIG_LEVEL_BKIN_DLYMS = (1<<25),/*!< \c BKIN_DLYMS -- BKin Delay, arg int Milliseconds */
 
 		/*!< These ones are not settable */
 	RIG_LEVEL_RAWSTR =	(1<<26),/*!< \c RAWSTR -- Raw (A/D) value for signal strength, specific to each rig, arg int */
@@ -707,8 +714,8 @@ typedef unsigned long setting_t;
  */
 enum rig_func_e {
 	RIG_FUNC_NONE =    	0,	/*!< '' -- No Function */
-    RIG_FUNC_FAGC =    	(1<<0),	/*!< \c FAGC -- Fast AGC */
-    RIG_FUNC_NB =	    	(1<<1),	/*!< \c NB -- Boise Blanker */
+	RIG_FUNC_FAGC =    	(1<<0),	/*!< \c FAGC -- Fast AGC */
+	RIG_FUNC_NB =	    	(1<<1),	/*!< \c NB -- Noise Blanker */
 	RIG_FUNC_COMP =    	(1<<2),	/*!< \c COMP -- Speech Compression */
 	RIG_FUNC_VOX =    	(1<<3),	/*!< \c VOX -- Voice Operated Relay */
 	RIG_FUNC_TONE =    	(1<<4),	/*!< \c TONE -- CTCSS Tone */
@@ -778,9 +785,11 @@ typedef enum {
 	RIG_MODE_SAM =          (1<<16),/*!< \c SAM -- Synchronous AM double sideband */
 	RIG_MODE_SAL =          (1<<17),/*!< \c SAL -- Synchronous AM lower sideband */
 	RIG_MODE_SAH =          (1<<18),/*!< \c SAH -- Synchronous AM upper (higher) sideband */
-	RIG_MODE_DSB =			(1<<19) /*!< \c DSB -- Double sideband suppressed carrier */
+	RIG_MODE_DSB =			(1<<19), /*!< \c DSB -- Double sideband suppressed carrier */
+    RIG_MODE_TESTS_MAX               /*!< \c MUST ALWAYS BE LAST, Max Count for dumpcaps.c */
 } rmode_t;
 
+
 /** \brief macro for backends, not to be used by rig_set_mode et al. */
 #define RIG_MODE_SSB  	(RIG_MODE_USB|RIG_MODE_LSB)
 
@@ -860,7 +869,7 @@ struct tuning_step_list {
  * this means the rig allows its passband width to be
  * set to any value ranging from the lowest to the
  * highest value (if any) in the list for that mode.
- * The RIG_TS_ANY value, if present, must
+ * The RIG_FLT_ANY value, if present, must
  * be the last one in the list.
  *
  * The width field is the narrowest passband in a transmit/receive chain
@@ -1417,6 +1426,7 @@ struct rig_state {
   freq_t current_freq;	/*!< Frequency currently set */
   rmode_t current_mode;	/*!< Mode currently set */
   pbwidth_t current_width;	/*!< Passband width currently set */
+  vfo_t tx_vfo;		/*!< Tx VFO currently set */
 
 };
 
