@@ -1,8 +1,9 @@
 /*
  *  Hamlib Interface - list of known rigs
- *  Copyright (c) 2000-2008 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2003 by Frank Singleton
+ *  Copyright (c) 2000-2009 by Stephane Fillod
  *
- *	$Id: riglist.h,v 1.73 2008/11/02 12:45:04 fillods Exp $
+ *	$Id: riglist.h,v 1.76 2009/01/29 22:54:40 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -89,6 +90,8 @@
 #define RIG_MODEL_VR5000 RIG_MAKE_MODEL(RIG_YAESU, 26)
 #define RIG_MODEL_FT450 RIG_MAKE_MODEL(RIG_YAESU, 27)
 #define RIG_MODEL_FT950 RIG_MAKE_MODEL(RIG_YAESU, 28)
+#define RIG_MODEL_FT2000 RIG_MAKE_MODEL(RIG_YAESU, 29)
+#define RIG_MODEL_FT9000 RIG_MAKE_MODEL(RIG_YAESU, 30)
 
 	/*
 	 * Kenwood
@@ -124,6 +127,7 @@
 #define RIG_MODEL_TMV7 RIG_MAKE_MODEL(RIG_KENWOOD, 27)
 #define RIG_MODEL_TS480 RIG_MAKE_MODEL(RIG_KENWOOD, 28)
 #define RIG_MODEL_K3 RIG_MAKE_MODEL(RIG_KENWOOD, 29)
+#define RIG_MODEL_TRC80 RIG_MAKE_MODEL(RIG_KENWOOD, 30)
 
 	/*
 	 * Icom
@@ -344,6 +348,8 @@
 #define RIG_MODEL_WR3700 RIG_MAKE_MODEL(RIG_WINRADIO, 7)
 #define RIG_MODEL_G303 RIG_MAKE_MODEL(RIG_WINRADIO, 8)
 #define RIG_MODEL_G313 RIG_MAKE_MODEL(RIG_WINRADIO, 9)
+#define RIG_MODEL_G305 RIG_MAKE_MODEL(RIG_WINRADIO, 10)
+#define RIG_MODEL_G315 RIG_MAKE_MODEL(RIG_WINRADIO, 11)
 
 	/*
 	 * Ten Tec
