@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kachina backend - 505DSP description
- *  Copyright (c) 2001-2002 by Stephane Fillod
+ *  Copyright (c) 2001-2004 by Stephane Fillod
  *
- *	$Id: 505dsp.c,v 1.4 2002/08/16 17:43:01 fillods Exp $
+ *	$Id: 505dsp.c,v 1.9 2006/10/07 17:42:14 csete Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -24,6 +24,8 @@
 #include "config.h"
 #endif
 
+#include <stdlib.h>
+
 #include <hamlib/rig.h>
 #include "kachina.h"
 
@@ -34,20 +36,18 @@
 
 #define K505DSP_FUNC (RIG_FUNC_FAGC|RIG_FUNC_NB|RIG_FUNC_TONE|RIG_FUNC_COMP)
 
-#define K505DSP_LEVEL_ALL (RIG_LEVEL_SQLSTAT|RIG_LEVEL_STRENGTH|RIG_LEVEL_RFPOWER|RIG_LEVEL_KEYSPD|RIG_LEVEL_BKINDL|RIG_LEVEL_CWPITCH)
+#define K505DSP_LEVEL_ALL (RIG_LEVEL_PREAMP|RIG_LEVEL_ATT|RIG_LEVEL_IF|RIG_LEVEL_RAWSTR|RIG_LEVEL_RFPOWER|RIG_LEVEL_KEYSPD|RIG_LEVEL_BKINDL|RIG_LEVEL_CWPITCH)
 
 #define K505DSP_PARM_ALL (RIG_PARM_NONE)
 
 #define K505DSP_VFO (RIG_VFO_A)
 
-#define K505DSP_STR_CAL { 2, { \
-		{    0, -60 }, \
-		{  127,  20 }, \
-	} }
+#define dBm2S9(x) ((x)+73)
 
-static const struct kachina_priv_caps k505dsp_priv_caps = {
-		K505DSP_STR_CAL
-};
+#define K505DSP_STR_CAL { 2, { \
+		{    0, dBm2S9(-130) }, \
+		{  127, dBm2S9(20) }, \
+	} }
 
 /*
  * 505DSP rig capabilities.
@@ -62,12 +62,12 @@ const struct rig_caps k505dsp_caps = {
 .rig_model =  RIG_MODEL_505DSP,
 .model_name = "505DSP",
 .mfg_name =  "Kachina",
-.version =  "0.1",
+.version =  "0.3",
 .copyright =  "LGPL",
-.status =  RIG_STATUS_UNTESTED,
+.status =  RIG_STATUS_ALPHA,
 .rig_type =  RIG_TYPE_COMPUTER,
 .ptt_type =  RIG_PTT_NONE,
-.dcd_type =  RIG_DCD_NONE,
+.dcd_type =  RIG_DCD_RIG,
 .port_type =  RIG_PORT_SERIAL,
 .serial_rate_min =  9600,
 .serial_rate_max =  9600,
@@ -82,7 +82,7 @@ const struct rig_caps k505dsp_caps = {
 
 .has_get_func =  K505DSP_FUNC,
 .has_set_func =  K505DSP_FUNC,
-.has_get_level =  K505DSP_LEVEL_ALL,
+.has_get_level =  RIG_LEVEL_RAWSTR,
 .has_set_level =  RIG_LEVEL_SET(K505DSP_LEVEL_ALL),
 .has_get_parm =  K505DSP_PARM_ALL,
 .has_set_parm =  RIG_PARM_SET(K505DSP_PARM_ALL),
@@ -151,11 +151,13 @@ const struct rig_caps k505dsp_caps = {
 		{RIG_MODE_FM, kHz(6)},
 		RIG_FLT_END,
 	},
-.priv =  (void*)&k505dsp_priv_caps,
+.str_cal = K505DSP_STR_CAL,
 
 .set_freq =  kachina_set_freq,
 .set_mode =  kachina_set_mode,
 
+.get_level =  kachina_get_level,
+
 };
 
 /*
