@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TH-G71 description
- *  Copyright (c) 2003-2005 by Stephane Fillod
+ *  Copyright (c) 2003-2008 by Stephane Fillod
  *
- *	$Id: thg71.c,v 1.19 2006/03/14 20:06:46 pa4tu Exp $
+ *	$Id: thg71.c,v 1.21 2008/05/04 21:15:17 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -121,10 +121,11 @@ const struct rig_caps thg71_caps = {
 
 .chan_list =  { 
 		{  1,  199, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* normal MEM */
-		{  200,219, RIG_MTYPE_EDGE , {TH_CHANNEL_CAPS}}, /* U/L MEM */
-		{  220,220, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* Priority */
-		{  221,222, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* Call 0/1 */
-		{  223,231, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* Band VFO */
+		{  200,209, RIG_MTYPE_EDGE , {TH_CHANNEL_CAPS}}, /* L MEM */
+		{  210,219, RIG_MTYPE_EDGE , {TH_CHANNEL_CAPS}}, /* U MEM */
+		{  220,220, RIG_MTYPE_PRIO , {TH_CHANNEL_CAPS}}, /* Priority */
+		{  221,222, RIG_MTYPE_CALL , {TH_CHANNEL_CAPS}}, /* Call 0/1 */
+		{  223,231, RIG_MTYPE_BAND , {TH_CHANNEL_CAPS}}, /* Band VFO */
 			 RIG_CHAN_END,
 		   },
 
