@@ -1,7 +1,7 @@
 /*
  * Hamlib backend library for the DCU rotor command set.
  *
- * rotorez.c - (C) Nate Bargmann 2003 (n0nb at arrl.net)
+ * rotorez.c - (C) Nate Bargmann 2003, 2009 (n0nb at arrl.net)
  *
  * This shared library provides an API for communicating
  * via serial interface to a Hy-Gain or Yaesu rotor using
@@ -11,8 +11,10 @@
  * Rotor-EZ is a trademark of Idiom Press
  * Hy-Gain is a trademark of MFJ Enterprises
  *
+ * Tested on a HAM-IV with the Rotor-EZ V1.4S interface installed.
  *
- *    $Id: rotorez.c,v 1.10 2008/10/26 13:50:30 y32kn Exp $
+ *
+ *    $Id: rotorez.c,v 1.14 2009/01/25 16:14:39 fillods Exp $
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -39,11 +41,13 @@
 #include <stdlib.h>             /* Standard library definitions */
 #include <string.h>             /* String function definitions */
 #include <unistd.h>             /* UNIX standard function definitions */
+#include <ctype.h>              /* for isdigit function */
 
 #include "hamlib/rotator.h"
 #include "serial.h"
 #include "misc.h"
 #include "register.h"
+#include "iofunc.h"
 
 #include "rotorez.h"
 
@@ -60,6 +64,26 @@ struct rotorez_rot_priv_data {
  */
 
 static int rotorez_send_priv_cmd(ROT *rot, const char *cmd);
+static int rotorez_flush_buffer(ROT *rot);
+
+/*
+ * local configuration parameters
+ */
+static const struct confparams rotorez_cfg_params[] = {
+	{ TOK_ENDPT, "endpt", "Endpoint option", "Endpoint option",
+		NULL, RIG_CONF_CHECKBUTTON, { }
+	},
+	{ TOK_JAM, "jam", "Jam protection", "Jam protection",
+		NULL, RIG_CONF_CHECKBUTTON, { }
+	},
+	{ TOK_OVRSHT, "oversht", "Overshoot option", "Overshoot option",
+		NULL, RIG_CONF_CHECKBUTTON, { }
+	},
+	{ TOK_UNSTICK, "unstick", "Unstick option", "Unstick option",
+		NULL, RIG_CONF_CHECKBUTTON, { }
+	},
+	{ RIG_CONF_END, NULL, }
+};
 
 /* *************************************
  *
@@ -70,16 +94,17 @@ static int rotorez_send_priv_cmd(ROT *rot, const char *cmd);
 
 
 /*
- * Rotor-EZ enhanced rotor capabilities
+ * Idiom Press Rotor-EZ enhanced rotor capabilities for
+ * Hy-Gain CD45, Ham-II, Ham-III, Ham IV and all TailTwister rotors
  */
 
 const struct rot_caps rotorez_rot_caps = {
   .rot_model =          ROT_MODEL_ROTOREZ,
   .model_name =         "Rotor-EZ",
   .mfg_name =           "Idiom Press",
-  .version =            "0.2",
+  .version =            "0.5",
   .copyright = 	        "LGPL",
-  .status =             RIG_STATUS_UNTESTED,
+  .status =             RIG_STATUS_BETA,
   .rot_type =           ROT_TYPE_OTHER,
   .port_type =          RIG_PORT_SERIAL,
   .serial_rate_min =    4800,
@@ -90,8 +115,8 @@ const struct rot_caps rotorez_rot_caps = {
   .serial_handshake =   RIG_HANDSHAKE_NONE,
   .write_delay =        0,
   .post_write_delay =   500,
-  .timeout =            5000,
-  .retry =              3,
+  .timeout =            1500,
+  .retry =              2,
 
   .min_az = 	        0,
   .max_az =  	        360,
@@ -99,6 +124,7 @@ const struct rot_caps rotorez_rot_caps = {
   .max_el =  	        0,
 
   .priv =  NULL,	/* priv */
+  .cfgparams =  rotorez_cfg_params,
 
   .rot_init =           rotorez_rot_init,
   .rot_cleanup =        rotorez_rot_cleanup,
@@ -111,14 +137,15 @@ const struct rot_caps rotorez_rot_caps = {
 
 
 /*
- * RotorCard enhanced rotor capabilities
+ * Idiom Press RotorCard enhanced rotor capabilities for
+ * Yaesu SDX and DXA series rotors
  */
 
 const struct rot_caps rotorcard_rot_caps = {
   .rot_model =          ROT_MODEL_ROTORCARD,
   .model_name =         "RotorCard",
   .mfg_name =           "Idiom Press",
-  .version =            "0.2",
+  .version =            "0.5",
   .copyright = 	        "LGPL",
   .status =             RIG_STATUS_UNTESTED,
   .rot_type =           ROT_TYPE_OTHER,
@@ -131,8 +158,8 @@ const struct rot_caps rotorcard_rot_caps = {
   .serial_handshake =   RIG_HANDSHAKE_NONE,
   .write_delay =        0,
   .post_write_delay =   500,
-  .timeout =            5000,
-  .retry =              3,
+  .timeout =            1500,
+  .retry =              2,
 
   .min_az = 	        0,
   .max_az =  	        360,
@@ -140,6 +167,7 @@ const struct rot_caps rotorcard_rot_caps = {
   .max_el =  	        0,
 
   .priv =  NULL,	/* priv */
+  .cfgparams =  rotorez_cfg_params,
 
   .rot_init =           rotorez_rot_init,
   .rot_cleanup =        rotorez_rot_cleanup,
@@ -159,7 +187,7 @@ const struct rot_caps dcu_rot_caps = {
   .rot_model =          ROT_MODEL_DCU,
   .model_name =         "DCU-1/DCU-1X",
   .mfg_name =           "Hy-Gain",
-  .version =            "0.2",
+  .version =            "0.5",
   .copyright = 	        "LGPL",
   .status =             RIG_STATUS_UNTESTED,
   .rot_type =           ROT_TYPE_OTHER,
@@ -172,8 +200,8 @@ const struct rot_caps dcu_rot_caps = {
   .serial_handshake =   RIG_HANDSHAKE_NONE,
   .write_delay =        0,
   .post_write_delay =   500,
-  .timeout =            5000,
-  .retry =              3,
+  .timeout =            1500,
+  .retry =              2,
 
   .min_az = 	        0,
   .max_az =  	        360,
@@ -286,7 +314,7 @@ static int rotorez_rot_set_position(ROT *rot, azimuth_t azimuth, elevation_t ele
 static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth, elevation_t *elevation) {
   struct rot_state *rs;
   char cmdstr[5] = "AI1;";
-  char az[5];          /* read azimuth string */
+  char az[5];      /* read azimuth string */
   char *p;
   azimuth_t tmp = 0;
   int err;
@@ -296,14 +324,37 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth, elevation_t *e
   if (!rot)
     return -RIG_EINVAL;
 
-  err = rotorez_send_priv_cmd(rot, cmdstr);
-  if (err != RIG_OK)
-    return err;
+  do {
+    err = rotorez_send_priv_cmd(rot, cmdstr);
+    if (err != RIG_OK)
+      return err;
 
-  rs = &rot->state;
-  err = read_block(&rs->rotport, az, AZ_READ_LEN);
-  if (err != AZ_READ_LEN)
-    return -RIG_ETRUNC;
+    rs = &rot->state;
+
+    err = read_block(&rs->rotport, az, AZ_READ_LEN);
+    if (err != AZ_READ_LEN)
+      return -RIG_ETRUNC;
+
+    /* The azimuth string should be ';xxx' beginning at offset 0.  If the
+     * ';' is not there, it's likely the RotorEZ has received an invalid
+     * command and the buffer needs to be flushed.  See rotorez_flush_buffer()
+     * definition below for a complete description.
+     */
+    if (az[0] != ';') {
+        err = rotorez_flush_buffer(rot);
+        if (err == -RIG_EIO)
+            return err;
+        else
+            err = -RIG_EINVAL;
+    } else if (err == AZ_READ_LEN && az[0] == ';') {
+        /* Check if remaining chars are digits if az[0] == ';' */
+        for (p = az + 1;p < az + 4; p++)
+            if (isdigit(*p))
+                continue;
+            else
+                err = -RIG_EINVAL;
+    }
+  } while (err == -RIG_EINVAL);
 
   /*
    * Rotor-EZ returns a four octet string consisting of a ';' followed
@@ -316,11 +367,13 @@ static int rotorez_rot_get_position(ROT *rot, azimuth_t *azimuth, elevation_t *e
   rig_debug(RIG_DEBUG_TRACE, "%s: \"%s\" after conversion = %.1f\n",
             __func__, p, tmp);
 
-  if (tmp < 0 || tmp > 359)
+  if (tmp == 360)
+      tmp = 0;
+  else if (tmp < 0 || tmp > 359)
     return -RIG_EINVAL;
 
   *azimuth = tmp;
-  *elevation = 0;               /* assume aiming at the horizon */
+  *elevation = 0;               /* RotorEZ does not support elevation */
   rig_debug(RIG_DEBUG_TRACE,
             "%s: azimuth = %.1f deg; elevation = %.1f deg\n",
             __func__, *azimuth, *elevation);
@@ -353,36 +406,65 @@ static int rotorez_rot_stop(ROT *rot) {
 /*
  * Send configuration character
  *
- * token is ignored
  * Rotor-EZ interface will act on these commands immediately --
- * no other command or command terminator is needed
+ * no other command or command terminator is needed.  Expects token
+ * define in rotorez.h and *val of '1' or '0' (enable/disable).
  */
 
 static int rotorez_rot_set_conf(ROT *rot, token_t token, const char *val) {
-  int err;
+    char cmdstr[2];
+    char c;
+    int err;
 
-  rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+    rig_debug(RIG_DEBUG_TRACE, "%s: token = %d, *val = %c\n",
+              __func__, token, *val);
 
-  if (!rot)
-    return -RIG_EINVAL;
+    if (!rot)
+        return -RIG_EINVAL;
 
-  switch(*val) {
-  case 'E':             /* Enable endpoint option */
-  case 'e':             /* Disable endpoint option */
-  case 'J':             /* Enable jam protection */
-  case 'j':             /* Disable jam protection -- not recommended */
-  case 'O':             /* Enable overshoot option */
-  case 'o':             /* Disable overshoot option */
-  case 'S':             /* Enable unstick option */
-  case 's':             /* Disable unstick option */
-    err = rotorez_send_priv_cmd(rot, val);
+    if (*val < '0' || *val > '1')
+        return -RIG_EINVAL;
+
+    switch(token) {
+    case TOK_ENDPT:             /* Endpoint option */
+        if (*val == '1')
+            c = 'E';
+        else
+            c = 'e';
+        break;
+    case TOK_JAM:               /* Jam protection */
+        if (*val == '1')
+            c = 'J';
+        else
+            c = 'j';
+        break;
+    case TOK_OVRSHT:            /* Overshoot option */
+        if (*val == '1')
+            c = 'O';
+        else
+            c = 'o';
+        break;
+    case TOK_UNSTICK:           /* Unstick option */
+        if (*val == '1')
+            c = 'S';
+        else
+            c = 's';
+        break;
+    default:
+        return -RIG_EINVAL;
+    }
+    rig_debug(RIG_DEBUG_TRACE, "%s: c = %c, *val = %c\n", __func__, c, *val);
+    snprintf(cmdstr, sizeof(cmdstr), "%c", c);
+
+    rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s, *val = %c\n",
+              __func__, cmdstr, *val);
+
+    err = rotorez_send_priv_cmd(rot, cmdstr);
     if (err != RIG_OK)
-      return err;
-  
+        return err;
+
     return RIG_OK;
-  default:
-    return -RIG_EINVAL;
-  }
 }
 
 
@@ -408,6 +490,42 @@ static int rotorez_send_priv_cmd(ROT *rot, const char *cmdstr) {
 }
 
 
+/*
+ * Flush the serial input buffer
+ *
+ * If the RotorEZ should receive an invalid command, such as an the ';'
+ * character while the rotor is not in motion, as sent by the rotorez_rot_stop
+ * function or the 'S' command from `rotctl', it will output the following
+ * string, "C2000 IDIOM V1.4S " into the input buffer.  This function flushes
+ * the buffer by reading it until a timeout occurs.  Once the timeout occurs,
+ * this function returns and the buffer is presumed to be empty.
+ */
+
+static int rotorez_flush_buffer(ROT *rot) {
+    struct rot_state *rs;
+    char garbage[32];          /* read buffer */
+    int err = 0;
+    size_t MAX = 31;
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    if (!rot)
+        return -RIG_EINVAL;
+
+    rs = &rot->state;
+    do {
+        err = read_block(&rs->rotport, garbage, MAX);
+
+        /* Oops!  An IO error was encountered.  Bail out! */
+        if (err == -RIG_EIO)
+            return -RIG_EIO;
+    }
+    while (err != -RIG_ETIMEOUT);
+
+    return RIG_OK;
+}
+
+
 /*
  * Initialize backend
  */
@@ -423,4 +541,3 @@ DECLARE_INITROT_BACKEND(rotorez)
   return RIG_OK;
 }
 
-
