@@ -1,7 +1,7 @@
 /*
  * Hamlib backend library for the DCU rotor command set.
  *
- * rotorez.h - (C) Nate Bargmann 2003 (n0nb at arrl.net)
+ * rotorez.h - (C) Nate Bargmann 2003, 2009 (n0nb at arrl.net)
  *
  * This shared library provides an API for communicating
  * via serial interface to a Hy-Gain or Yaesu rotor using
@@ -9,7 +9,7 @@
  * supports the Hy-Gain DCU-1.
  *
  *
- *    $Id: rotorez.h,v 1.5 2003/04/16 22:30:41 fillods Exp $
+ *    $Id: rotorez.h,v 1.8 2009/01/25 16:14:39 fillods Exp $
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -31,12 +31,24 @@
 #ifndef _ROT_ROTOREZ_H
 #define _ROT_ROTOREZ_H 1
 
+#include "token.h"
+
 #define AZ_READ_LEN 4
 
 extern const struct rot_caps rotorez_rot_caps;
 extern const struct rot_caps rotorcard_rot_caps;
 extern const struct rot_caps dcu_rot_caps;
 
+/*
+ * Tokens used by rotorez_rot_set_conf and the 'C' command in rotctl
+ * and rotctld followed by a value of '0' to disable a Rotor-EZ option
+ * and '1' to enable it.
+ */
+#define TOK_ENDPT   TOKEN_BACKEND(1)
+#define TOK_JAM     TOKEN_BACKEND(2)
+#define TOK_OVRSHT  TOKEN_BACKEND(3)
+#define TOK_UNSTICK TOKEN_BACKEND(4)
+
 /* 
  * API local implementation
  *
