@@ -1,8 +1,8 @@
 /*
  *  Hamlib RPC backend - main file
- *  Copyright (c) 2001-2003 by Stephane Fillod
+ *  Copyright (c) 2001-2008 by Stephane Fillod
  *
- *	$Id: rpcrig_backend.c,v 1.16 2003/05/16 16:31:46 fillods Exp $
+ *	$Id: rpcrig_backend.c,v 1.20 2008/10/31 22:14:10 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -25,6 +25,7 @@
 #endif
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>  /* String function definitions */
 #include <unistd.h>  /* UNIX standard function definitions */
 #include <math.h>
@@ -762,7 +763,7 @@ static int rpcrig_set_parm(RIG *rig, setting_t parm, value_t val)
 	priv = (struct rpcrig_priv_data*)rig->state.priv;
 
 	setting_t2x(parm, &arg.setting);
-	if (RIG_LEVEL_IS_FLOAT(parm))
+	if (RIG_PARM_IS_FLOAT(parm))
 			arg.val.f = val.f;
 	else
 			arg.val.i = val.i;
@@ -795,7 +796,7 @@ static int rpcrig_get_parm(RIG *rig, setting_t parm, value_t *val)
 		return -RIG_EPROTO;
 	}
 	if (res->rigstatus == RIG_OK) {
-			if (RIG_LEVEL_IS_FLOAT(parm))
+			if (RIG_PARM_IS_FLOAT(parm))
 				val->f = res->val_res_u.val.f;
 			else
 				val->i = res->val_res_u.val.i;
@@ -1008,7 +1009,7 @@ struct rig_caps rpcrig_caps = {
   .mfg_name =       "Hamlib",
   .version =        "0.3",
   .copyright = 	 "LGPL",
-  .status =         RIG_STATUS_ALPHA,
+  .status =         RIG_STATUS_BETA,
   .rig_type =       RIG_TYPE_OTHER,
   .targetable_vfo = 	 0,
   .ptt_type =       RIG_PTT_NONE,
