@@ -7,18 +7,18 @@
  * \file src/locator.c
  * \brief locator and bearing conversion interface
  * \author Stephane Fillod and the Hamlib Group
- * \date 2000-2006
+ * \date 2000-2009
  *
  *  Hamlib Interface - locator, bearing, and conversion calls
  */
 
 /*
  *  Hamlib Interface - locator and bearing conversion calls
- *  Copyright (c) 2001-2006 by Stephane Fillod
+ *  Copyright (c) 2001-2009 by Stephane Fillod
  *  Copyright (c) 2003 by Nate Bargmann
  *  Copyright (c) 2003 by Dave Hines
  *
- *	$Id: locator.c,v 1.19 2006/10/15 00:27:51 aa6e Exp $
+ *	$Id: locator.c,v 1.21 2009/02/20 12:26:13 fillods Exp $
  *
  *  Code to determine bearing and range was taken from the Great Circle,
  *  by S. R. Sampson, N5OWK.
@@ -539,29 +539,22 @@ int HAMLIB_API qrb(double lon1, double lat1, double lon2, double lat2, double *d
 	 * This method is easier than the one in the handbook
 	 */
 
-	/* Short Path */
+	
 	*distance = ARC_IN_KM * RADIAN * arc;
 
-	/* This formula seems to work with very small distances
-	 *
-	 * I found it on the Web at:
-	 * http://williams.best.vwh.net/avform.htm#Crs
-	 *
-	 * Strangely, all the computed values were negative thus the
-	 * sign reversal below.
-	 * - N0NB
-	 */
-	az = RADIAN * fmod(atan2(sin(lon1 - lon2) * cos(lat2),
-				 cos(lat1) * sin(lat2) - sin(lat1) * cos(lat2) * cos(lon1 - lon2)), 2 * M_PI);
-	if (lon1 > lon2) {
-		az -= 360.;
-		*azimuth = -az;
-	} else {
-		if (az >= 0.0)
-			*azimuth = az;
-		else
-			*azimuth = -az;
-	}
+	/* Short Path */
+	/* Change to azimuth computation by Dave Freese, W1HKJ */
+
+	az = RADIAN * atan2(sin(lon2 - lon1) * cos(lat2),
+			    (cos(lat1) * sin(lat2) - sin(lat1) * cos(lat2) * cos(lon2 - lon1)));
+
+	az = fmod(360.0 + az, 360.0);
+	if (az < 0.0)
+		az += 360.0;
+	else if (az >= 360.0)
+		az -= 360.0;
+
+	*azimuth = floor(az + 0.5);
 	return RIG_OK;
 }
 
