@@ -1,8 +1,9 @@
 /*
  *  Hamlib Interface - main file
- *  Copyright (c) 2000-2008 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2009 by Stephane Fillod
+ *  Copyright (c) 2000-2003 by Frank Singleton
  *
- *	$Id: rotator.c,v 1.24 2008/09/23 22:02:39 fillods Exp $
+ *	$Id: rotator.c,v 1.27 2009/02/20 12:26:13 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -29,7 +30,7 @@
  * \file src/rotator.c
  * \brief Rotator interface
  * \author Stephane Fillod
- * \date 2000-2008
+ * \date 2000-2009
  *
  * Hamlib interface is a frontend implementing rotator wrapper functions.
  */
@@ -234,7 +235,7 @@ ROT * HAMLIB_API rot_init(rot_model_t rot_model)
 	break;
 
 	case RIG_PORT_NETWORK:
-	strncpy(rs->rotport.pathname, "localhost:4533", FILPATHLEN);
+	strncpy(rs->rotport.pathname, "127.0.0.1:4533", FILPATHLEN);
 	break;
 
 	default:
@@ -365,7 +366,7 @@ int HAMLIB_API rot_open(ROT *rot)
  * \brief close the communication to the rot
  * \param rot	The #ROT handle of the rotator to be closed
  *
- * Closes communication to a radio which \a ROT handle has been passed
+ * Closes communication to a rotator which \a ROT handle has been passed
  * by argument that was previously open with rot_open().
  *
  * \return RIG_OK if the operation has been sucessful, otherwise 
@@ -410,6 +411,9 @@ int HAMLIB_API rot_close(ROT *rot)
 		case RIG_PORT_USB:
 			usb_port_close(&rs->rotport);
 			break;
+		case RIG_PORT_NETWORK:
+			network_close(&rs->rotport);
+			break;
 		default:
 			close(rs->rotport.fd);
 		}
