@@ -1,10 +1,10 @@
 /*
  *  Hamlib Interface - serial communication low-level support
- *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2005 by Stephane Fillod and Frank Singleton
  *  Parts of the PTT handling are derived from soundmodem, an excellent
  *  ham packet softmodem written by Thomas Sailer, HB9JNX.
  *
- *	$Id: serial.c,v 1.43 2004/10/02 20:37:24 fillods Exp $
+ *	$Id: serial.c,v 1.45 2006/10/15 00:27:52 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -22,6 +22,16 @@
  *
  */
 
+/**
+ * \addtogroup rig_internal
+ * @{
+ */
+
+/**
+ * \brief Serial port IO
+ * \file serial.c
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -72,20 +82,12 @@
 #include <sys/ioccom.h>
 #endif
 
-/*
- * Open serial port using rig.state data
- *
- *
- * input: ptr to rig.state structure, with serial port
- *        populated. (eg: "/dev/ttyS1").
- * 
- * returns:
- *
- * 0 if OK or negative value on error.
- *
+/**
+ * \brief Open serial port using rig.state data
+ * \param rp port data structure (must spec port id eg /dev/ttyS1)
+ * \return RIG_OK or < 0 if error
  */
-
-int HAMLIB_API serial_open(port_t *rp) {
+int HAMLIB_API serial_open(hamlib_port_t *rp) {
 
   int fd;				/* File descriptor for the port */
   int err;
@@ -118,8 +120,12 @@ int HAMLIB_API serial_open(port_t *rp) {
   return RIG_OK;
 }
 
-
-int HAMLIB_API serial_setup(port_t *rp)
+/**
+ * \brief Set up Serial port according to requests in port
+ * \param rp
+ * \return RIG_OK or < 0
+ */
+int HAMLIB_API serial_setup(hamlib_port_t *rp)
 {
   int fd;
   /* There's a lib replacement for termios under Mingw */
@@ -356,28 +362,45 @@ int HAMLIB_API serial_setup(port_t *rp)
 }
 
 
-/*
- * Flush all characters waiting in RX buffer.
+/**
+ * \brief Flush all characters waiting in RX buffer.
+ * \param p
+ * \return RIG_OK
  */
-
-int HAMLIB_API serial_flush( port_t *p )
+int HAMLIB_API serial_flush(hamlib_port_t *p )
 {
   tcflush(p->fd, TCIFLUSH);
 
   return RIG_OK;
 }
 
-int ser_open(port_t *p)
+/**
+ * \brief Open serial port
+ * \param p
+ * \return fd
+ */
+int ser_open(hamlib_port_t *p)
 {
 	return (p->fd = OPEN(p->pathname, O_RDWR | O_NOCTTY | O_NDELAY));
 }
 
-int ser_close(port_t *p)
+/**
+ * \brief Close serial port
+ * \param p fd
+ * \return RIG_OK or < 0
+ */
+int ser_close(hamlib_port_t *p)
 {
 	return CLOSE(p->fd);
 }
 
-int HAMLIB_API ser_set_rts(port_t *p, int state)
+/**
+ * \brief Set Request to Send (RTS) bit
+ * \param p
+ * \param state true/false
+ * \return RIG_OK or < 0
+ */
+int HAMLIB_API ser_set_rts(hamlib_port_t *p, int state)
 {
 	unsigned int y = TIOCM_RTS;
 
@@ -396,11 +419,12 @@ int HAMLIB_API ser_set_rts(port_t *p, int state)
 #endif
 }
 
-/*
- * assumes state not NULL
- * p is supposed to be &rig->state.rigport
+/**
+ * \brief Get RTS bit
+ * \param p supposed to be &rig->state.rigport
+ * \param state non-NULL
  */
-int HAMLIB_API ser_get_rts(port_t *p, int *state)
+int HAMLIB_API ser_get_rts(hamlib_port_t *p, int *state)
 {
   int retcode;
   unsigned int y;
@@ -411,7 +435,13 @@ int HAMLIB_API ser_get_rts(port_t *p, int *state)
   return retcode < 0 ? -RIG_EIO : RIG_OK;
 }
 
-int HAMLIB_API ser_set_dtr(port_t *p, int state)
+/**
+ * \brief Set Data Terminal Ready (DTR) bit
+ * \param p
+ * \param state true/false
+ * \return RIG_OK or < 0
+ */
+int HAMLIB_API ser_set_dtr(hamlib_port_t *p, int state)
 {
 	unsigned int y = TIOCM_DTR;
 
@@ -430,7 +460,12 @@ int HAMLIB_API ser_set_dtr(port_t *p, int state)
 #endif
 }
 
-int HAMLIB_API ser_get_dtr(port_t *p, int *state)
+/**
+ * \brief Get DTR bit
+ * \param p supposed to be &rig->state.rigport
+ * \param state non-NULL
+ */
+int HAMLIB_API ser_get_dtr(hamlib_port_t *p, int *state)
 {
   int retcode;
   unsigned int y;
@@ -441,7 +476,13 @@ int HAMLIB_API ser_get_dtr(port_t *p, int *state)
   return retcode < 0 ? -RIG_EIO : RIG_OK;
 }
 
-int HAMLIB_API ser_set_brk(port_t *p, int state)
+/**
+ * \brief Set Break
+ * \param p
+ * \param state (ignored?)
+ * \return RIG_OK or < 0
+ */
+int HAMLIB_API ser_set_brk(hamlib_port_t *p, int state)
 {
 #if defined(TIOCSBRK) && defined(TIOCCBRK)
 	return IOCTL(p->fd, state ? TIOCSBRK : TIOCCBRK, 0 ) < 0 ?
@@ -451,11 +492,12 @@ int HAMLIB_API ser_set_brk(port_t *p, int state)
 #endif
 }
 
-/*
- * assumes state not NULL
- * p is supposed to be &rig->state.rigport
+/**
+ * \brief Get Carrier (CI?) bit
+ * \param p supposed to be &rig->state.rigport
+ * \param state non-NULL
  */
-int HAMLIB_API ser_get_car(port_t *p, int *state)
+int HAMLIB_API ser_get_car(hamlib_port_t *p, int *state)
 {
   int retcode;
   unsigned int y;
@@ -466,7 +508,12 @@ int HAMLIB_API ser_get_car(port_t *p, int *state)
   return retcode < 0 ? -RIG_EIO : RIG_OK;
 }
 
-int HAMLIB_API ser_get_cts(port_t *p, int *state)
+/**
+ * \brief Get Clear to Send (CTS) bit
+ * \param p supposed to be &rig->state.rigport
+ * \param state non-NULL
+ */
+int HAMLIB_API ser_get_cts(hamlib_port_t *p, int *state)
 {
   int retcode;
   unsigned int y;
@@ -477,7 +524,12 @@ int HAMLIB_API ser_get_cts(port_t *p, int *state)
   return retcode < 0 ? -RIG_EIO : RIG_OK;
 }
 
-int HAMLIB_API ser_get_dsr(port_t *p, int *state)
+/**
+ * \brief Get Data Set Ready (DSR) bit
+ * \param p supposed to be &rig->state.rigport
+ * \param state non-NULL
+ */
+int HAMLIB_API ser_get_dsr(hamlib_port_t *p, int *state)
 {
   int retcode;
   unsigned int y;
@@ -488,3 +540,4 @@ int HAMLIB_API ser_get_dsr(port_t *p, int *state)
   return retcode < 0 ? -RIG_EIO : RIG_OK;
 }
 
+/** @} */
