@@ -2,7 +2,7 @@
  *  Hamlib TenTenc backend - TT-565 description
  *  Copyright (c) 2004-2008 by Stephane Fillod & Martin Ewing
  *
- *	$Id: orion.c,v 1.26 2008/06/19 04:26:52 aa6e Exp $
+ *	$Id: orion.c,v 1.31 2009/02/14 21:33:22 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -41,6 +41,8 @@
  * Fixed bug in tt565_reset (to send "XX" instead of "X")
  * Filtered rig info string to ensure all graphics.
  * Big reliability improvement (for fldigi, v 2.062a) 2/15/2008
+ * Jan., 2009:
+ * Remove RIG_LEVEL_STRENGTH, so that frontend can handle it.
  */
 
 /* Known issues & to-do list:
@@ -80,6 +82,7 @@
 #include "misc.h"
 #include "idx_builtin.h"
 #include "orion.h"
+#include <cal.h>
 
 #ifdef TT565_TIME 
 /**
@@ -163,7 +166,7 @@ int tt565_transaction(RIG *rig, const char *cmd, int cmd_len, char *data, int *d
 	                was written.  We report the problem if debugging,
 	                and issue another read in hopes of eventual success.
 	                */
-	            rig_debug(RIG_DEBUG_ERR,
+	            rig_debug(RIG_DEBUG_WARN,
 	                "** retry after delay (io=%d, retry=%d) **\n", 
 	                passcount, itry);
 		        *data_len = data_len_init;	/* restore orig. buffer length */
@@ -694,6 +697,7 @@ int tt565_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
  * \param rit Rx incremental tuning, Hz
  * \returns RIG_OK or < 0
  * \brief Set Rx incremental tuning
+ * Note: command rit != 0 ==> rit "on"; rit == 0 ==> rit "off"
  */
 int tt565_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 {
@@ -747,6 +751,7 @@ int tt565_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
  * \param xit Tx incremental tuning, Hz
  * \returns RIG_OK or < 0
  * \brief Set Tx incremental tuning (Main TRx only)
+ * Note: command xit != 0 ==> xit "on"; xit == 0 ==> xit "off"
  */
 int tt565_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
 {
@@ -1138,7 +1143,8 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 			else val->f = 0.0;	/* SWR in Receive = 0.0 */
 		break;
 
-	case RIG_LEVEL_RAWSTR:
+	case RIG_LEVEL_RAWSTR:		/* provide uncalibrated raw strength, int */
+	    /* NB: RIG_LEVEL_STRENGTH is handled in the frontend */
   		lvl_len = sizeof(lvlbuf);	
 		retval = tt565_transaction (rig, "?S" EOM, 3, lvlbuf, &lvl_len);
 		if (retval != RIG_OK)
@@ -1151,10 +1157,20 @@ int tt565_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 		}
 
 		if (lvlbuf[2] == 'R') {
-			val->i = atoi(strchr(lvlbuf+3,
-				vfo == RIG_VFO_SUB ? 'S' : 'M')+1);  /* check main/sub logic */
+			char *raw_field, *raw_field2;
+			/* response is @SRMnnnSnnn, incl main & sub rx. */
+			/* TT's spec indicates variable length data 1-3 digits */
+			if (vfo==RIG_VFO_SUB) {		/* look at sub rx info */
+				raw_field = strchr(lvlbuf+3, 'S')+1; /* length may vary */
+				}
+			else {				/* look at main rx info */
+				raw_field = lvlbuf+4;
+				raw_field2 = strchr(raw_field,'S'); /* position may vary */
+				if (raw_field2) *raw_field2 = '\0'; /* valid string */
+				}
+			val->i = atoi(raw_field);	/* get raw value */
 		}
-			else val->i = 0;	/* S-meter in xmit = 0 */
+		else val->i = 0;	/* S-meter in xmit => 0 */
 		break;
 
 	case RIG_LEVEL_RFPOWER:
