@@ -103,8 +103,7 @@ struct tt565_priv_data {
 				RIG_LEVEL_AF|RIG_LEVEL_AGC| \
 				RIG_LEVEL_VOXGAIN|RIG_LEVEL_VOX|RIG_LEVEL_ANTIVOX| \
 				RIG_LEVEL_COMP|RIG_LEVEL_PREAMP| \
-				RIG_LEVEL_SWR|RIG_LEVEL_ATT)| \
-				RIG_LEVEL_STRENGTH
+				RIG_LEVEL_SWR|RIG_LEVEL_ATT)
 
 /** \brief Orion Tx/Rx Antennas*/
 #define TT565_ANTS (RIG_ANT_1|RIG_ANT_2) 
@@ -193,7 +192,7 @@ const struct rig_caps tt565_caps = {
 .rig_model =  RIG_MODEL_TT565,
 .model_name = "TT-565 Orion",
 .mfg_name =  "Ten-Tec",
-.version =  "0.3",
+.version =  "0.4",
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
