@@ -1,9 +1,9 @@
 /*
- * dumpcaps.c - Copyright (C) 2000-2008 Stephane Fillod
+ * dumpcaps.c - Copyright (C) 2000-2009 Stephane Fillod
  * This programs dumps the capabilities of a backend rig.
  *
  *
- *    $Id: dumpcaps.c,v 1.48 2008/09/21 19:10:59 fillods Exp $  
+ *    $Id: dumpcaps.c,v 1.52 2009/01/28 22:49:58 fillods Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -219,6 +219,26 @@ int dumpcaps (RIG* rig, FILE *fout)
 		fprintf(fout, " none");
 	fprintf(fout, "\n");
 
+	fprintf(fout, "CTCSS:");
+	for(i=0; caps->ctcss_list && i<60 && caps->ctcss_list[i] != 0; i++) {
+		fprintf(fout, " %d.%1d",caps->ctcss_list[i]/10,caps->ctcss_list[i]%10);
+	}
+	if (i == 0)
+		fprintf(fout, " none");
+	else
+		fprintf(fout, " Hz, %d tones", i);
+	fprintf(fout, "\n");
+
+	fprintf(fout, "DCS:");
+	for(i=0; caps->dcs_list && i<128 && caps->dcs_list[i] != 0; i++) {
+		fprintf(fout, " %d",caps->dcs_list[i]);
+	}
+	if (i == 0)
+		fprintf(fout, " none");
+	else
+		fprintf(fout, ", %d codes", i);
+	fprintf(fout, "\n");
+
 	sprintf_func(prntbuf, caps->has_get_func);
 	fprintf(fout, "Get functions: %s\n", prntbuf);
 
@@ -246,7 +266,7 @@ int dumpcaps (RIG* rig, FILE *fout)
 			backend_warnings++;
 	}
 	fprintf(fout, "Extra levels:");
-	rig_ext_level_foreach(rig, print_ext, NULL);
+	rig_ext_level_foreach(rig, print_ext, fout);
 	fprintf(fout, "\n");
 
 	sprintf_parm_gran(prntbuf, caps->has_get_parm, caps->parm_gran);
@@ -339,7 +359,7 @@ int dumpcaps (RIG* rig, FILE *fout)
 	fprintf(fout, "\n");
 
         fprintf(fout, "Bandwidths:");
-	for (i=1; i < 1<<10; i<<=1) {
+	for (i=1; i < RIG_MODE_TESTS_MAX; i<<=1) {
 		pbwidth_t pbnorm = rig_passband_normal(rig, i);
 
 		if (pbnorm == 0)
