@@ -1,11 +1,12 @@
 /*
- * rigctl_parse.c - (C) Stephane Fillod 2000-2008
+ * rigctl_parse.c - (C) Stephane Fillod 2000-2009
+ *                  (C) Terry Embry 2008-2009
  *
  * This program test/control a radio using Hamlib.
  * It takes commands in interactive mode as well as 
  * from command line options.
  *
- * $Id: rigctl_parse.c,v 1.9 2008/10/27 22:23:36 fillods Exp $  
+ * $Id: rigctl_parse.c,v 1.16 2009/02/06 17:28:38 fillods Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -275,7 +276,8 @@ static int scanfc(FILE *fin, const char *format, void *p)
 extern int interactive;
 extern int prompt;
 extern int opt_end;
-
+extern int vfo_mode;
+extern char send_cmd_term;
 
 int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 {
@@ -288,7 +290,6 @@ int rigctl_parse(RIG *my_rig, FILE *fin, FILE *fout, char *argv[], int argc)
 	char arg3[MAXARGSZ+1], *p3;
 	static int last_was_ret = 1;
 	vfo_t vfo = RIG_VFO_CURR;
-	int vfo_mode = 0;
 
 	if (interactive) {
 		if (prompt)
@@ -549,8 +550,11 @@ int print_conf_list(const struct confparams *cfp, rig_ptr_t data)
 	case RIG_CONF_CHECKBUTTON:
 		printf("\tCheck button.\n");
 		break;
+	case RIG_CONF_BUTTON:
+		printf("\tButton.\n");
+		break;
 	default:
-		printf("\tUnkown conf\n");
+		printf("\tUnknown conf\n");
 	}
 
 	return 1;  /* !=0, we want them all ! */
@@ -931,9 +935,10 @@ declare_proto_rig(get_dcs_sql)
 declare_proto_rig(set_split_freq)
 {
 	freq_t txfreq;
+	vfo_t txvfo = RIG_VFO_TX;
 
 	sscanf(arg1, "%"SCNfreq, &txfreq);
-	return rig_set_split_freq(rig, vfo, txfreq);
+	return rig_set_split_freq(rig, txvfo, txfreq);
 }
 
 /* 'i' */
@@ -941,8 +946,9 @@ declare_proto_rig(get_split_freq)
 {
 	int status;
 	freq_t txfreq;
-
-	status = rig_get_split_freq(rig, vfo, &txfreq);
+	vfo_t txvfo = RIG_VFO_TX;
+	
+	status = rig_get_split_freq(rig, txvfo, &txfreq);
 	if (status != RIG_OK)
 		return status;
 	if (interactive && prompt)
@@ -957,6 +963,7 @@ declare_proto_rig(set_split_mode)
 {
 	rmode_t mode;
 	int     width;
+	vfo_t txvfo = RIG_VFO_TX;
 
 #if 0
 	if (!strcmp(arg1, "?")) {
@@ -968,7 +975,7 @@ declare_proto_rig(set_split_mode)
 #endif
 	mode = rig_parse_mode(arg1);
 	sscanf(arg2, "%d", &width);
-	return rig_set_split_mode(rig, vfo, mode, (pbwidth_t) width);
+	return rig_set_split_mode(rig, txvfo, mode, (pbwidth_t) width);
 }
 
 /* 'x' */
@@ -977,8 +984,9 @@ declare_proto_rig(get_split_mode)
 	int status;
 	rmode_t mode;
 	pbwidth_t width;
+	vfo_t txvfo = RIG_VFO_TX;
 
-	status = rig_get_split_mode(rig, vfo, &mode, &width);
+	status = rig_get_split_mode(rig, txvfo, &mode, &width);
 	if (status != RIG_OK)
 		return status;
 	if (interactive && prompt)
@@ -1062,7 +1070,9 @@ declare_proto_rig(power2mW)
 	fprintf(fout, "Mode: ");
 	scanf("%d", &mode);
 	status = rig_power2mW(rig, &mwp, power, freq, (rmode_t) mode);
-	fprintf(fout, "Power: %d mW\n", mwp);
+	fprintf(fout, "rig_power2mW()-Power: %d mW\n", mwp);
+    status = rig_mW2power(rig, &power, mwp, freq, (rmode_t) mode);
+    fprintf(fout, "rig_mW2power()-Power ratio [0.0 .. 1.0]: %f\n", power);
 
 	return status;
 }
@@ -1097,6 +1107,9 @@ declare_proto_rig(set_level)
 			return -RIG_EINVAL;	/* no such parameter */
 
 		switch (cfp->type) {
+		case RIG_CONF_BUTTON:
+			/* arg is ignored */
+			break;
 		case RIG_CONF_CHECKBUTTON:
 		case RIG_CONF_COMBO:
 			sscanf(arg2, "%d", &val.i);
@@ -1151,6 +1164,10 @@ declare_proto_rig(get_level)
 			fprintf(fout, "%s: ", cmd->arg2);
 
 		switch (cfp->type) {
+		case RIG_CONF_BUTTON:
+			/* there's not sense in retrieving value of stateless button */
+			return -RIG_EINVAL;
+
 		case RIG_CONF_CHECKBUTTON:
 		case RIG_CONF_COMBO:
 			fprintf(fout, "%d\n", val.i);
@@ -1246,6 +1263,9 @@ declare_proto_rig(set_parm)
 			return -RIG_EINVAL;	/* no such parameter */
 
 		switch (cfp->type) {
+		case RIG_CONF_BUTTON:
+			/* arg is ignored */
+			break;
 		case RIG_CONF_CHECKBUTTON:
 		case RIG_CONF_COMBO:
 			sscanf(arg2, "%d", &val.i);
@@ -1300,6 +1320,9 @@ declare_proto_rig(get_parm)
 			fprintf(fout, "%s: ", cmd->arg2);
 
 		switch (cfp->type) {
+		case RIG_CONF_BUTTON:
+			/* there's not sense in retrieving value of stateless button */
+			return -RIG_EINVAL;
 		case RIG_CONF_CHECKBUTTON:
 		case RIG_CONF_COMBO:
 			fprintf(fout, "%d\n", val.i);
@@ -1400,98 +1423,156 @@ declare_proto_rig(scan)
 /* 'H' */
 declare_proto_rig(set_channel)
 {
-	const channel_cap_t *mem_caps = NULL;
-	const chan_t *chan_list;
-	channel_t chan;
+    const channel_cap_t *mem_caps = NULL;
+    const chan_t *chan_list;
+    channel_t chan;
+    int status;
+    char s[16];
 
-	return -RIG_ENIMPL;
+    rig_debug(RIG_DEBUG_TRACE, "set_channel: arg1[0] = %d\n", arg1[0]);
 
-	if (isdigit(arg1[0])) {
-		chan.vfo = RIG_VFO_MEM;
-		if (sscanf(arg1, "%d", &chan.channel_num) != 1)
-			return -RIG_EINVAL;
-		/*
-		 * find mem_caps in caps, we'll need it later
-		 */
-		chan_list = rig_lookup_mem_caps(rig, chan.channel_num);
-		if (chan_list)
-			mem_caps = &chan_list->mem_caps;
+    memset(&chan, 0, sizeof(channel_t));
 
-	} else {
-		chan.vfo = rig_parse_vfo(arg1);
-		chan.channel_num = 0;
+    if (isdigit(arg1[0])) {
+        chan.vfo = RIG_VFO_MEM;
+        if (sscanf(arg1, "%d", &chan.channel_num) != 1)
+            return -RIG_EINVAL;
+        /*
+         * find mem_caps in caps, we'll need it later
+         */
+        chan_list = rig_lookup_mem_caps(rig, chan.channel_num);
+        if (chan_list)
+            mem_caps = &chan_list->mem_caps;
 
-		/* TODO: mem_caps for VFO! */
-	}
+    } else {
+        chan.vfo = rig_parse_vfo(arg1);
+        chan.channel_num = 0;
 
-	if (!mem_caps)
-		return -RIG_ECONF;
+        /* TODO: mem_caps for VFO! */
+    }
 
-#ifdef FIXME
-	if (mem_caps->bank_num)
-		sscanf(arg1, "%d", &chan.bank_num);
-	if (mem_caps->vfo)
-		chan.vfo = rig_parse_vfo(arg1);
-	if (mem_caps->ant)
-		sscanf(arg1, "%d", &chan.ant);
-	if (mem_caps->freq)
-		sscanf(arg1, "%"SCNfreq, &chan.freq);
-	if (mem_caps->mode)
-		chan.mode = rig_parse_mode(arg1);
-	if (mem_caps->width)
-		sscanf(arg1, "%d", (int*)&chan.width);
+    if (!mem_caps)
+        return -RIG_ECONF;
 
-	if (mem_caps->tx_freq)
-		sscanf(arg1, "%"SCNfreq, &chan.tx_freq);
-	if (mem_caps->tx_mode)
-		chan.tx_mode = rig_parse_mode(arg1);
-	if (mem_caps->tx_width)
-		sscanf(arg1, "%d", (int*)&chan.tx_width);
+    rig_debug(RIG_DEBUG_TRACE, "set_channel: mem_caps->bank_num = %d, mem_caps->freq = %d\n", mem_caps->bank_num, mem_caps->freq);
 
-	if (mem_caps->split)
-		sscanf(arg1, "%d", &chan.split);
-	if (mem_caps->tx_vfo)
-		chan.tx_vfo = rig_parse_vfo(arg1);
-	if (mem_caps->rptr_shift)
-		chan.rptr_shift = rig_parse_rptr_shift(arg1);
-	if (mem_caps->rptr_offs)
-		sscanf(arg1, "%d", &chan.rptr_offs);
-	if (mem_caps->tuning_step)
-		sscanf(arg1, "%d", &chan.tuning_step);
-	if (mem_caps->rit)
-		sscanf(arg1, "%d", &chan.rit);
-	if (mem_caps->xit)
-		sscanf(arg1, "%d", &chan.xit);
-	if (mem_caps->funcs)
-		sscanf(arg1, "%x", &chan.funcs);
+    if (mem_caps->bank_num) {
+        printf("Bank Num: ");
+        scanf("%d", &chan.bank_num);
+    }
+    if (mem_caps->vfo) {
+        printf("vfo (VFOA,MEM,etc...): ");
+        scanf("%s", s);
+        chan.vfo = rig_parse_vfo(s);
+    }
+    if (mem_caps->ant) {
+        printf("ant: ");
+        scanf("%d", &chan.ant);
+    }
+    if (mem_caps->freq) {
+        printf("Frequency: ");
+        scanf("%"SCNfreq, &chan.freq);
+    }
+    if (mem_caps->mode) {
+        printf("mode (FM,LSB,etc...): ");
+        scanf("%s", s);
+        chan.mode = rig_parse_mode(s);
+    }
+    if (mem_caps->width) {
+        printf("width: ");
+        scanf("%ld", &chan.width);
+    }
+    if (mem_caps->tx_freq) {
+        printf("tx freq (VFOA,MEM,etc...): ");
+        scanf("%"SCNfreq, &chan.tx_freq);
+    }
+    if (mem_caps->tx_mode) {
+        printf("tx mode (FM,LSB,etc...): ");
+        scanf("%s", s);
+        chan.tx_mode = rig_parse_mode(s);
+    }
+    if (mem_caps->tx_width) {
+        printf("tx width: ");
+        scanf("%ld", &chan.tx_width);
+    }
+    if (mem_caps->split) {
+        printf("split (0,1): ");
+        scanf("%d", &status);
+        chan.split = status;
+    }
+    if (mem_caps->tx_vfo) {
+        printf("tx vfo (VFOA,MEM,etc...): ");
+        scanf("%s", s);
+        chan.tx_vfo = rig_parse_vfo(s);
+    }
+    if (mem_caps->rptr_shift) {
+        printf("rptr shift (+-0): "); 
+        scanf("%s", s);
+        chan.rptr_shift = rig_parse_rptr_shift(s);
+    }
+    if (mem_caps->rptr_offs) {
+        printf("rptr offset: ");
+        scanf("%ld", &chan.rptr_offs);
+    }
+    if (mem_caps->tuning_step) {
+        printf("tuning step: ");
+        scanf("%ld", &chan.tuning_step);
+    }
+    if (mem_caps->rit) {
+        printf("rit (Hz,0=off): ");
+        scanf("%ld", &chan.rit);
+    }
+    if (mem_caps->xit) {
+        printf("xit (Hz,0=off): ");
+        scanf("%ld", &chan.xit);
+    }
+    if (mem_caps->funcs) {
+        printf("funcs: ");
+        scanf("%lx", &chan.funcs);
+    }
 #if 0
-		/* for all levels, ask */
-	if (mem_caps->levels)
-		sscanf(arg1, "%d", &chan.levels);
+    /* for all levels, ask */
+    if (mem_caps->levels)
+        sscanf(arg1, "%d", &chan.levels);
 #endif
-	if (mem_caps->ctcss_tone)
-		sscanf(arg1, "%d", &chan.ctcss_tone);
-	if (mem_caps->ctcss_sql)
-		sscanf(arg1, "%d", &chan.ctcss_sql);
-	if (mem_caps->dcs_code)
-		sscanf(arg1, "%d", &chan.dcs_code);
-	if (mem_caps->dcs_sql)
-		sscanf(arg1, "%d", &chan.dcs_sql);
-	if (mem_caps->scan_group)
-		sscanf(arg1, "%d", &chan.scan_group);
-	if (mem_caps->flags)
-		sscanf(arg1, "%d", &chan.flags);
-	if (mem_caps->channel_desc)
-		strcpy(chan.channel_desc, arg1);
+    if (mem_caps->ctcss_tone) {
+        printf("ctcss tone freq in tenth of Hz (0=off): ");
+        scanf("%d", &chan.ctcss_tone);
+    }
+    if (mem_caps->ctcss_sql) {
+        printf("ctcss sql freq in tenth of Hz (0=off): ");
+        scanf("%d", &chan.ctcss_sql);
+    }
+    if (mem_caps->dcs_code) {
+        printf("dcs code: ");
+        scanf("%d", &chan.dcs_code);
+    }
+    if (mem_caps->dcs_sql) {
+        printf("dcs sql: ");
+        scanf("%d", &chan.dcs_sql);
+    }
+    if (mem_caps->scan_group) {
+        printf("scan group: ");
+        scanf("%d", &chan.scan_group);
+    }
+    if (mem_caps->flags) {
+        printf("flags: ");
+        scanf("%d", &chan.flags);
+    }
+    if (mem_caps->channel_desc) {
+        printf("channel desc: ");
+        scanf("%s", s);
+        strcpy(chan.channel_desc, s);
+    }
 #if 0
-	/* TODO: same as levels */
-	if (mem_caps->ext_levels)
-		sscanf(arg1, "%d", &chan.ext_levels);
+    /* TODO: same as levels */
+    if (mem_caps->ext_levels)
+        sscanf(arg1, "%d", &chan.ext_levels);
 #endif
 
-#endif
+    status = rig_set_channel(rig, &chan);
 
-	return RIG_OK;
+    return status;
 }
 
 /* 'h' */
@@ -1499,6 +1580,8 @@ declare_proto_rig(get_channel)
 {
 	int status;
 	channel_t chan;
+    
+    memset(&chan, 0, sizeof(channel_t));
 
 	if (isdigit(arg1[0])) {
 		chan.vfo = RIG_VFO_MEM;
@@ -1866,12 +1949,15 @@ declare_proto_rig(send_cmd)
 #define BUFSZ 128
 	char bufcmd[BUFSZ];
 	char buf[BUFSZ];
+	char eom_buf[4] = { 0xa, 0xd, 0, 0 };
 
 	/*
 	 * binary protocols enter values as \0xZZ\0xYY..
 	 */
 	backend_num = RIG_BACKEND_NUM(rig->caps->rig_model);
-	if (backend_num == RIG_YAESU || backend_num == RIG_ICOM ||
+	if (send_cmd_term == -1 ||
+			backend_num == RIG_YAESU ||
+			backend_num == RIG_ICOM ||
 			backend_num == RIG_KACHINA ||
 			backend_num == RIG_MICROTUNE) {
 		const char *p = arg1, *pp = NULL;
@@ -1880,18 +1966,23 @@ declare_proto_rig(send_cmd)
 			pp = p+1;
 			bufcmd[i] = strtol(p+1, (char **) &p, 0);
 		}
-		cmd_len = i-1;
 		/* must save length to allow 0x00 to be sent as part of a command
 		*/
+		cmd_len = i-1;
+
+		/* no End Of Message chars */
+		eom_buf[0] = '\0';
 	} else {
+		/* text protocol */
+
 		strncpy(bufcmd,arg1,BUFSZ);
-		bufcmd[BUFSZ-1] = '\0';
+		bufcmd[BUFSZ-2] = '\0';
 		cmd_len = strlen(bufcmd);
-		/*
-		 * assumes CR is end of line char
-		 * for all ascii protocols
-		 */
-		strcat(bufcmd, "\r");
+
+		/* Automatic termination char */
+		if (send_cmd_term != 0)
+			bufcmd[cmd_len++] = send_cmd_term;
+		eom_buf[2] = send_cmd_term;
 	}
 
 	rs = &rig->state;
@@ -1905,9 +1996,12 @@ declare_proto_rig(send_cmd)
 	if (interactive && prompt)
 		fprintf(fout, "%s: ", cmd->arg2);
 
-#define EOM "\0xa"
 	do {
-		retval = read_string(&rs->rigport, buf, BUFSZ, EOM, strlen(EOM));
+		/*
+		 * assumes CR or LF is end of line char
+		 * for all ascii protocols
+		 */
+		retval = read_string(&rs->rigport, buf, BUFSZ, eom_buf, strlen(eom_buf));
 		if (retval < 0)
 			break;
 	
