@@ -3,12 +3,13 @@
  *
  * ft450.c - (C) Nate Bargmann 2007 (n0nb at arrl.net)
  *           (C) Stephane Fillod 2008
+ *           (C) Terry Embry 2008-2009
  *
  * This shared library provides an API for communicating
  * via serial interface to an FT-450 using the "CAT" interface
  *
  *
- * $Id: ft450.c,v 1.4 2008/11/01 22:39:07 fillods Exp $
+ * $Id: ft450.c,v 1.12 2009/01/11 17:39:26 mrtembry Exp $
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -78,7 +79,7 @@ const struct rig_caps ft450_caps = {
 	[LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
 	[LVL_CWPITCH] = { .min = { .i = 400 }, .max = { .i = 800 }, .step = { .i = 100 } },
     },
-    .ctcss_list =         NULL,	/* TODO */
+    .ctcss_list =         common_ctcss_list,
     .dcs_list =           NULL,
     .preamp =             { 10, RIG_DBLST_END, }, /* TBC */
     .attenuator =         { 18, RIG_DBLST_END, }, /* TBC */
@@ -141,16 +142,21 @@ const struct rig_caps ft450_caps = {
 
     /* mode/filter list, .remember =  order matters! */
     .filters =            {
-        {RIG_MODE_SSB,  kHz(2.4)},  /* standard SSB filter bandwidth */
-        {RIG_MODE_CW,   kHz(2.4)},  /* normal CW filter */
-        {RIG_MODE_CW,   kHz(0.5)},  /* CW filter with narrow selection (must be installed!) */
-        {RIG_MODE_AM,   kHz(6)},    /* normal AM filter */
-        {RIG_MODE_AM,   kHz(2.4)},  /* AM filter with narrow selection (SSB filter switched in) */
-        {RIG_MODE_FM,   kHz(12)},   /* FM  */
+        {FT450_CW_RTTY_PKT_RX_MODES,  Hz(1800)},    /* Normal CW, RTTY, PKT/USER */
+        {FT450_CW_RTTY_PKT_RX_MODES,  Hz(500)},     /* Narrow CW, RTTY, PKT/USER */
+        {FT450_CW_RTTY_PKT_RX_MODES,  Hz(2400)},    /* Wide   CW, RTTY, PKT/USER */
+        {RIG_MODE_SSB,                Hz(2400)},    /* Normal SSB */
+        {RIG_MODE_SSB,                Hz(1800)},    /* Narrow SSB */
+        {RIG_MODE_SSB,                Hz(3000)},    /* Wide   SSB */
+        {RIG_MODE_AM,                 Hz(6000)},    /* Normal AM  */
+        {RIG_MODE_AM,                 Hz(3000)},    /* Narrow AM  */
+        {FT450_FM_RX_MODES,           Hz(12000)},   /* Normal FM  */
+        {FT450_FM_RX_MODES,           Hz(8000)},    /* Narrow FM  */
 
         RIG_FLT_END,
     },
 
+
     .priv =               NULL,           /* private data FIXME: */
 
     .rig_init =           newcat_init,
@@ -165,11 +171,11 @@ const struct rig_caps ft450_caps = {
     .set_vfo =            newcat_set_vfo,
     .get_vfo =            newcat_get_vfo,
     .set_ptt =            newcat_set_ptt,
-//    .get_ptt =            newcat_get_ptt,
-//    .set_split_vfo =      newcat_set_split_vfo,
-//    .get_split_vfo =      newcat_get_split_vfo,
-//    .set_rit =            newcat_set_rit,
-//    .get_rit =            newcat_get_rit,
+    .get_ptt =            newcat_get_ptt,
+    .set_split_vfo =      newcat_set_split_vfo,
+    .get_split_vfo =      newcat_get_split_vfo,
+    .set_rit =            newcat_set_rit,
+    .get_rit =            newcat_get_rit,
     .get_func =           newcat_get_func,
     .set_func =           newcat_set_func,
     .get_level =          newcat_get_level,
@@ -178,5 +184,22 @@ const struct rig_caps ft450_caps = {
     .set_mem =            newcat_set_mem,
     .vfo_op =             newcat_vfo_op,
     .get_info =           newcat_get_info,
+    .power2mW =           newcat_power2mW,
+    .mW2power =           newcat_mW2power,
+    .set_rptr_shift =     newcat_set_rptr_shift,
+    .get_rptr_shift =     newcat_get_rptr_shift,
+    .set_ctcss_tone =     newcat_set_ctcss_tone,
+    .get_ctcss_tone =     newcat_get_ctcss_tone,
+    .set_ctcss_sql  =     newcat_set_ctcss_sql,
+    .get_ctcss_sql  =     newcat_get_ctcss_sql,
+    .set_powerstat =      newcat_set_powerstat,
+    .get_powerstat =      newcat_get_powerstat,
+    .get_ts =             newcat_get_ts,
+    .set_ts =             newcat_set_ts,
+    .set_trn =            newcat_set_trn,
+    .get_trn =            newcat_get_trn,
+    .set_channel =        newcat_set_channel,
+    .get_channel =        newcat_get_channel,
+
 };
 
