@@ -8,7 +8,7 @@
  * via serial interface to an FT-450 using the "CAT" interface
  *
  *
- *    $Id: ft450.h,v 1.2 2008/11/01 22:39:07 fillods Exp $
+ *    $Id: ft450.h,v 1.4 2008/12/17 22:57:04 mrtembry Exp $
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -40,10 +40,19 @@
 
 /* Receiver caps */
 
-#define FT450_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_USB|RIG_MODE_LSB)
-#define FT450_SSB_CW_RX_MODES (RIG_MODE_CW|RIG_MODE_USB|RIG_MODE_LSB)
+/* FT450 USER-L == RIG_MODE_PKTLSB */
+/* FT450 USER-U == RIG_MODE_PKTUSB */
+/* */
+#define FT450_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|\
+		RIG_MODE_RTTY|RIG_MODE_RTTYR|RIG_MODE_PKTLSB|RIG_MODE_PKTUSB|RIG_MODE_PKTFM)
+#define FT450_SSB_CW_RX_MODES (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|\
+		RIG_MODE_RTTY|RIG_MODE_RTTYR|RIG_MODE_PKTLSB|RIG_MODE_PKTUSB)
 #define FT450_AM_RX_MODES (RIG_MODE_AM)
-#define FT450_FM_RX_MODES (RIG_MODE_FM)
+#define FT450_FM_RX_MODES (RIG_MODE_FM|RIG_MODE_PKTFM)
+#define FT450_CW_RX_MODES (RIG_MODE_CW|RIG_MODE_CWR)
+#define FT450_CW_RTTY_PKT_RX_MODES (RIG_MODE_RTTY|RIG_MODE_RTTYR|\
+        RIG_MODE_PKTUSB|RIG_MODE_PKTLSB|RIG_MODE_CW|RIG_MODE_CWR)
+
 
 
 /* TRX caps */
@@ -64,7 +73,9 @@
                 RIG_FUNC_FBKIN|RIG_FUNC_MN)
 
 #define FT450_VFO_OPS (RIG_OP_TUNE|RIG_OP_CPY|RIG_OP_XCHG|\
-                RIG_OP_UP|RIG_OP_DOWN|RIG_OP_BAND_UP|RIG_OP_BAND_DOWN)
+               RIG_OP_UP|RIG_OP_DOWN|RIG_OP_BAND_UP|RIG_OP_BAND_DOWN|\
+               RIG_OP_TOGGLE)
+
 
 /* TBC */
 #define FT450_STR_CAL { 3, \
