@@ -1,14 +1,14 @@
 /*
  * hamlib - (C) Frank Singleton 2000,2001 (vk3fcs@ix.netcom.com)
+ *          (C) Stephane Fillod 2000-2009
  *
  * ft847.c - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
+ *           (C) Stephane Fillod 2000-2009
+ *
  * This shared library provides an API for communicating
  * via serial interface to an FT-847 using the "CAT" interface.
  *
- *
- * $Id: ft847.c,v 1.31 2006/10/07 15:51:38 csete Exp $  
- *
- *
+ * $Id: ft847.c,v 1.34 2009/02/20 12:33:52 fillods Exp $  
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -58,10 +58,11 @@
 #include "yaesu.h"
 #include "ft847.h"
 #include "misc.h"
+#include "bandplan.h"
 
 /* prototypes */
 
-static int ft847_send_priv_cmd(RIG *rig, unsigned char ci);
+static int ft847_send_priv_cmd(RIG *rig, int cmd_index);
 
 
 /* Native ft847 cmd set prototypes. These are READ ONLY as each */
@@ -159,8 +160,8 @@ static const yaesu_cmd_set_t ncmd[] = {
  */
 
 
-#define FT847_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_FM)
-#define FT847_SSB_CW_RX_MODES (RIG_MODE_CW|RIG_MODE_SSB)
+#define FT847_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB|RIG_MODE_FM)
+#define FT847_SSB_CW_RX_MODES (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_SSB)
 #define FT847_AM_FM_RX_MODES (RIG_MODE_AM|RIG_MODE_FM)
 
 /* tx doesn't have WFM.
@@ -171,7 +172,21 @@ static const yaesu_cmd_set_t ncmd[] = {
 #define FT847_OTHER_TX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_FM)
 #define FT847_AM_TX_MODES (RIG_MODE_AM)
 
-#define FT847_FUNC_ALL (RIG_FUNC_FAGC|RIG_FUNC_NB|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_TONE|RIG_FUNC_TSQL|RIG_FUNC_SBKIN|RIG_FUNC_FBKIN)	/* fix */
+#define FT847_FUNC_ALL RIG_FUNC_NONE /* none available through CAT */
+
+#define FT847_LEVEL_ALL (RIG_LEVEL_RAWSTR|RIG_LEVEL_STRENGTH|RIG_LEVEL_ALC)
+
+#define FT847_VFOS (RIG_VFO_MAIN|RIG_VFO_SUB)
+
+/* FT-847 has different antennas connectors, but no rig_set_ant() ability */
+#define FT847_ANTS RIG_ANT_1
+
+#define FT847_STR_CAL { 3, \
+	{ \
+		{   0, -60 }, /* S0 */ \
+		{  16,   0 }, /* S9 */ \
+		{  31,  60 }, /* +60 dB */ \
+	} }
 
 /*
  * ft847 rigs capabilities.
@@ -179,17 +194,16 @@ static const yaesu_cmd_set_t ncmd[] = {
  * Also this struct is READONLY!
  */
 
-
 const struct rig_caps ft847_caps = {
 .rig_model =  RIG_MODEL_FT847,
 .model_name = "FT-847", 
 .mfg_name =  "Yaesu", 
-.version =  "0.2", 
+.version =  "0.4",
 .copyright =  "LGPL",
-.status =  RIG_STATUS_ALPHA,
+.status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
 .ptt_type =  RIG_PTT_RIG,
-.dcd_type =  RIG_DCD_NONE,
+.dcd_type =  RIG_DCD_RIG,
 .port_type =  RIG_PORT_SERIAL,
 .serial_rate_min =  4800,
 .serial_rate_max =  57600,
@@ -199,33 +213,55 @@ const struct rig_caps ft847_caps = {
 .serial_handshake =  RIG_HANDSHAKE_NONE, 
 .write_delay =  FT847_WRITE_DELAY,
 .post_write_delay =  FT847_POST_WRITE_DELAY,
-.timeout =  100,
-.retry =  0, 
+.timeout =  1000,
+.retry =  0,
 
 .has_get_func =  RIG_FUNC_NONE,
-.has_set_func =  FT847_FUNC_ALL, 
-.has_get_level =  RIG_LEVEL_NONE,	/* FIXME! */
+.has_set_func =  RIG_FUNC_NONE, /* none available through CAT */
+.has_get_level =  FT847_LEVEL_ALL,
 .has_set_level =  RIG_LEVEL_NONE,
 .has_get_parm =  RIG_PARM_NONE,
-.has_set_parm =  RIG_PARM_NONE,	/* FIXME: parms */
+.has_set_parm =  RIG_PARM_NONE,
 .level_gran =  {}, 		/* granularity */
 .parm_gran =  {},
-.ctcss_list =  NULL,	/* FIXME: CTCSS/DCS list */
-.dcs_list =  NULL,
-.preamp =   { RIG_DBLST_END, },	/* FIXME! */
+.ctcss_list =  NULL,	/* FIXME */
+.dcs_list =  NULL,	/* FIXME */
+.preamp =   { RIG_DBLST_END, },	/* no preamp/att in CAT */
 .attenuator =   { RIG_DBLST_END, },
-.max_rit =  Hz(9999),
+.max_rit =  Hz(0),
 .max_xit =  Hz(0),
 .max_ifshift =  Hz(0),
-.targetable_vfo =  RIG_TARGETABLE_FREQ,
+.targetable_vfo =  RIG_TARGETABLE_FREQ|RIG_TARGETABLE_MODE,
 .transceive =  RIG_TRN_OFF,
 .bank_qty =   0,
 .chan_desc_sz =  0,
+.str_cal = FT847_STR_CAL,
 
-.chan_list =  { RIG_CHAN_END, },	/* FIXME: memory chan list: 78 */
+.chan_list =  { RIG_CHAN_END, }, /* FIXME: memory chan list: 78, but only in clonable mode? */
+
+.rx_range_list1 =  {
+    {kHz(100),MHz(30),FT847_ALL_RX_MODES,-1,-1}, /* rx range begin */
+    {MHz(36),MHz(76),FT847_ALL_RX_MODES,-1,-1},
+    {MHz(108),MHz(174),FT847_ALL_RX_MODES,-1,-1},
+    {MHz(420),MHz(512),FT847_ALL_RX_MODES,-1,-1},
+
+    RIG_FRNG_END, }, /* rx range end */
+
+.tx_range_list1 =  {
+    FRQ_RNG_HF(1,FT847_OTHER_TX_MODES, W(5),W(100),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_HF(1,FT847_AM_TX_MODES, W(1),W(25),FT847_VFOS,FT847_ANTS),
+
+    FRQ_RNG_6m(2,FT847_OTHER_TX_MODES, W(5),W(100),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_6m(2,FT847_AM_TX_MODES, W(1),W(25),FT847_VFOS,FT847_ANTS),
+
+    FRQ_RNG_2m(2,FT847_OTHER_TX_MODES, W(1),W(50),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_2m(2,FT847_AM_TX_MODES, W(1),W(12.5),FT847_VFOS,FT847_ANTS),
+
+    FRQ_RNG_70cm(2,FT847_OTHER_TX_MODES, W(1),W(50),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_70cm(2,FT847_AM_TX_MODES, W(1),W(12.5),FT847_VFOS,FT847_ANTS),
+
+    RIG_FRNG_END, }, /* tx range end */
 
-.rx_range_list1 =  { RIG_FRNG_END, },    /* FIXME: enter region 1 setting */
-.tx_range_list1 =  { RIG_FRNG_END, },
 .rx_range_list2 =  
   { {kHz(100),MHz(30),FT847_ALL_RX_MODES,-1,-1}, /* rx range begin */
     {MHz(36),MHz(76),FT847_ALL_RX_MODES,-1,-1},
@@ -235,41 +271,18 @@ const struct rig_caps ft847_caps = {
     RIG_FRNG_END, }, /* rx range end */
 
 .tx_range_list2 = 
-  { {MHz(1.8),1999999,FT847_OTHER_TX_MODES,W(5),W(100)},	/* 5-100W class */
-    {MHz(1.8),1999999,FT847_AM_TX_MODES,W(1),W(25)},	/* 1-25W class */
+  {
+    FRQ_RNG_HF(2,FT847_OTHER_TX_MODES, W(5),W(100),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_HF(2,FT847_AM_TX_MODES, W(1),W(25),FT847_VFOS,FT847_ANTS),
 
-    {MHz(3.5),3999999,FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(3.5),3999999,FT847_AM_TX_MODES,W(1),W(25)},
+    FRQ_RNG_6m(2,FT847_OTHER_TX_MODES, W(5),W(100),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_6m(2,FT847_AM_TX_MODES, W(1),W(25),FT847_VFOS,FT847_ANTS),
 
-    {MHz(7),MHz(7.3),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(7),MHz(7.3),FT847_AM_TX_MODES,W(1),W(25)},
+    FRQ_RNG_2m(2,FT847_OTHER_TX_MODES, W(1),W(50),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_2m(2,FT847_AM_TX_MODES, W(1),W(12.5),FT847_VFOS,FT847_ANTS),
 
-    {MHz(10),MHz(10.150),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(10),MHz(10.150),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(14),MHz(14.350),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(14),MHz(14.350),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(18.068),MHz(18.168),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(18.068),MHz(18.168),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(21),MHz(21.450),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(21),MHz(21.450),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(24.890),MHz(24.990),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(24.890),MHz(24.990),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(28),MHz(29.7),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(28),MHz(29.7),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(50),MHz(54),FT847_OTHER_TX_MODES,W(5),W(100)},
-    {MHz(50),MHz(54),FT847_AM_TX_MODES,W(1),W(25)},
-
-    {MHz(144),MHz(148),FT847_OTHER_TX_MODES,W(1),W(50)}, 
-    {MHz(144),MHz(148),FT847_AM_TX_MODES,W(1),W(12.5)}, 
-
-    {MHz(430),MHz(440),FT847_OTHER_TX_MODES,W(1),W(50)}, /* check range */
-    {MHz(430),MHz(440),FT847_AM_TX_MODES,W(1),W(12.5)},
+    FRQ_RNG_70cm(2,FT847_OTHER_TX_MODES, W(1),W(50),FT847_VFOS,FT847_ANTS),
+    FRQ_RNG_70cm(2,FT847_AM_TX_MODES, W(1),W(12.5),FT847_VFOS,FT847_ANTS),
 
     RIG_FRNG_END, },
 
@@ -285,8 +298,8 @@ const struct rig_caps ft847_caps = {
   },  
       /* mode/filter list, .remember =  order matters! */
 .filters =  {
-		{RIG_MODE_SSB|RIG_MODE_CW, kHz(2.2)},
-		{RIG_MODE_CW, Hz(500)},
+		{RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_CWR, kHz(2.2)},
+		{RIG_MODE_CW|RIG_MODE_CWR, Hz(500)},
 		{RIG_MODE_AM, kHz(9)},
 		{RIG_MODE_AM, kHz(2.2)},
 		{RIG_MODE_FM, kHz(15)},
@@ -304,11 +317,16 @@ const struct rig_caps ft847_caps = {
 .get_freq =  ft847_get_freq,		/* get freq */
 .set_mode =  ft847_set_mode,		/* set mode */
 .get_mode =  ft847_get_mode,		/* get mode */
-.set_vfo =  ft847_set_vfo,		/* set vfo */
-.get_vfo =  ft847_get_vfo,		/* get vfo */
+.set_split_vfo  = ft847_set_split_vfo,
+.get_split_vfo  = ft847_get_split_vfo,
+.set_split_freq = ft847_set_split_freq,
+.get_split_freq = ft847_get_split_freq,
+.set_split_mode = ft847_set_split_mode,
+.get_split_mode = ft847_get_split_mode,
 .set_ptt =  ft847_set_ptt,		/* set ptt */
 .get_ptt =  ft847_get_ptt,		/* get ptt */
-
+.get_dcd =  ft847_get_dcd,		/* get dcd */
+.get_level = ft847_get_level,           /* get level */
 };
 
 /*
@@ -323,6 +341,8 @@ const struct rig_caps ft847_caps = {
 int ft847_init(RIG *rig) {
   struct ft847_priv_data *p;
   
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called \n", __func__);
+
   if (!rig)
     return -RIG_EINVAL;
   
@@ -332,15 +352,8 @@ int ft847_init(RIG *rig) {
     return -RIG_ENOMEM;
   }
 
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847:ft847_init called \n");
 
-  /* 
-   * Copy complete native cmd set to private cmd storage area 
-   */
-
-  memcpy(p->pcs,ncmd,sizeof(ncmd));
-
-  p->current_vfo =  RIG_VFO_MAIN;	/* default to VFO_MAIN */
+  p->sat_mode = RIG_SPLIT_OFF;
   rig->state.priv = (void*)p;
   
   return RIG_OK;
@@ -377,9 +390,7 @@ int ft847_open(RIG *rig) {
 
   rig_debug(RIG_DEBUG_VERBOSE,"ft847:ft847_open called \n");
 
-  ft847_send_priv_cmd(rig,FT_847_NATIVE_CAT_ON);
-
-  return RIG_OK;
+  return ft847_send_priv_cmd(rig,FT_847_NATIVE_CAT_ON);
 }
 
 /*
@@ -393,6 +404,7 @@ int ft847_close(RIG *rig) {
 
   rig_debug(RIG_DEBUG_VERBOSE,"ft847:ft847_close called \n");
 
+  /* don't care about return value */
   ft847_send_priv_cmd(rig,FT_847_NATIVE_CAT_OFF);
 
   return RIG_OK;
@@ -404,35 +416,63 @@ int ft847_close(RIG *rig) {
  *
  */
 
-static int ft847_send_priv_cmd(RIG *rig, unsigned char ci) {
+static int ft847_send_priv_cmd(RIG *rig, int cmd_index) {
 
   struct rig_state *rig_s;
   struct ft847_priv_data *p;
   unsigned char *cmd;		/* points to sequence to send */
-  unsigned char cmd_index;	/* index of sequence to send */
  
   if (!rig)
     return -RIG_EINVAL;
 
-
-  p = (struct ft847_priv_data*)rig->state.priv;
-  rig_s = &rig->state;
-  
-  cmd_index = ci;		/* get command */
-
-  if (! p->pcs[cmd_index].ncomp) {
+  if (! ncmd[cmd_index].ncomp) {
     rig_debug(RIG_DEBUG_VERBOSE,"ft847: Attempt to send incomplete sequence \n");
     return -RIG_EINVAL;
   }
 
-  cmd = (unsigned char *) p->pcs[cmd_index].nseq; /* get native sequence */
-  write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
+  p = (struct ft847_priv_data*)rig->state.priv;
+  rig_s = &rig->state;
   
-  return RIG_OK;
+  cmd = (unsigned char *) ncmd[cmd_index].nseq; /* get native sequence */
 
+  return write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
 }
 
 
+/*
+ * opcode_vfo() copy into cmd the 5 byte command designated by cmd_index,
+ * and patch the opcode with VFO targetting (MAIN 0x0-, SAT RX 0x1-, SAT TX 0x2-)
+ */
+static int opcode_vfo(RIG *rig, unsigned char * cmd, int cmd_index, vfo_t vfo)
+{
+  struct ft847_priv_data *p = (struct ft847_priv_data*)rig->state.priv;
+
+  memcpy(cmd, &ncmd[cmd_index].nseq,YAESU_CMD_LENGTH);  
+
+  /* If the sat_mode is not enabled,
+   * then leave the OpCode untouched (MAIN VFO) */
+
+  if (p->sat_mode == RIG_SPLIT_ON) {
+	  switch(vfo) {
+	  case RIG_VFO_CURR:
+	  case RIG_VFO_MAIN:
+	    cmd[4] &= 0x0f;
+	    cmd[4] |= 0x10;  /* MAIN VFO -> SAT RX VFO */
+	    break;
+	  case RIG_VFO_SUB:
+	  case RIG_VFO_TX:
+	    cmd[4] &= 0x0f;
+	    cmd[4] |= 0x20;  /* SAT TX VFO */
+	    break;
+	  default:
+	    rig_debug(RIG_DEBUG_WARN,"%s: Unsupported VFO %s\n",
+			    rig_strvfo(vfo));
+	    return -RIG_EINVAL;		/* sorry, wrong VFO */
+	  }
+  }
+  return RIG_OK;
+}
+
 
 /*
  * Set frequency to freq Hz. Note 10 Hz resolution -- YUK -- FS
@@ -443,8 +483,8 @@ static int ft847_send_priv_cmd(RIG *rig, unsigned char ci) {
 int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq) {
   struct rig_state *rig_s;
   struct ft847_priv_data *p;
-  unsigned char *cmd;		/* points to sequence to send */
-  unsigned char cmd_index;	/* index of sequence to send */
+  unsigned char p_cmd[YAESU_CMD_LENGTH]; /* sequence to send */
+  int ret;
 
   if (!rig)
     return -RIG_EINVAL;
@@ -453,39 +493,18 @@ int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq) {
 
   rig_s = &rig->state;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: requested freq = %"PRIfreq" Hz \n", freq);
-
-
-  /* 
-   * Copy native cmd freq_set to private cmd storage area 
-   */
-
-
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", rig_strvfo(vfo));
+  rig_debug(RIG_DEBUG_VERBOSE,"ft847: requested freq = %"PRIfreq" Hz, vfo=%s\n",
+		  freq, rig_strvfo(vfo));
   
-  if (vfo == RIG_VFO_CURR)
-	vfo = p->current_vfo;
+  ret = opcode_vfo(rig, p_cmd, FT_847_NATIVE_CAT_SET_FREQ_MAIN, vfo);
+  if (ret != RIG_OK)
+	  return ret;
 
-  switch(vfo) {
-  case RIG_VFO_MAIN:
-    cmd_index = FT_847_NATIVE_CAT_SET_FREQ_MAIN;
-    break;
-  default:
-    rig_debug(RIG_DEBUG_VERBOSE,"ft847: Unknown  VFO \n");
-    return -RIG_EINVAL;		/* sorry, wrong VFO */
-  }
+  to_bcd_be(p_cmd,freq/10,8);	/* store bcd format in in p_cmd */
 
-  memcpy(p->p_cmd,&ncmd[cmd_index].nseq,YAESU_CMD_LENGTH);  
+  rig_debug(RIG_DEBUG_VERBOSE,"ft847: requested freq after conversion = %"PRIll" Hz \n", from_bcd_be(p_cmd,8)* 10 );
 
-  to_bcd_be(p->p_cmd,freq/10,8);	/* store bcd format in in p_cmd */
-				/* TODO -- fix 10Hz resolution -- FS */
-
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: requested freq after conversion = %"PRIll" Hz \n", from_bcd_be(p->p_cmd,8)* 10 );
-
-  cmd = p->p_cmd; /* get native sequence */
-  write_block(&rig_s->rigport, (char *) cmd, YAESU_CMD_LENGTH);
-
-  return RIG_OK;
+  return write_block(&rig_s->rigport, (char*)p_cmd, YAESU_CMD_LENGTH);
 }
 
 #define MD_LSB  0x00
@@ -503,37 +522,28 @@ static int get_freq_and_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
 				pbwidth_t *width) {
   struct rig_state *rs = &rig->state;
   struct ft847_priv_data *p;
-  unsigned char *cmd;		/* points to sequence to send */
+  unsigned char p_cmd[YAESU_CMD_LENGTH]; /* sequence to send */
   unsigned char cmd_index;	/* index of sequence to send */
   unsigned char data[8];
   int n;
 
   p = (struct ft847_priv_data*)rs->priv;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", rig_strvfo(vfo));
-  
-  if (vfo == RIG_VFO_CURR)
-	vfo = p->current_vfo;
+  rig_debug(RIG_DEBUG_VERBOSE,"ft847: %s vfo =%s \n",
+		  __func__, rig_strvfo(vfo));
 
-  /*
-   * TODO:
-   *	FT_847_NATIVE_CAT_GET_FREQ_MODE_STATUS_SAT_RX
-   *	FT_847_NATIVE_CAT_GET_FREQ_MODE_STATUS_SAT_TX
-   */
-  switch(vfo) {
-  case RIG_VFO_MAIN:
-    cmd_index = FT_847_NATIVE_CAT_GET_FREQ_MODE_STATUS_MAIN;
-    break;
+  cmd_index = FT_847_NATIVE_CAT_GET_FREQ_MODE_STATUS_MAIN;
 
-  default:
-    rig_debug(RIG_DEBUG_VERBOSE,"ft847: Unknown  VFO \n");
-    return -RIG_EINVAL;		/* sorry, wrong VFO */
-  }
+  memcpy(p_cmd,&ncmd[cmd_index].nseq,YAESU_CMD_LENGTH);  
 
-  memcpy(p->p_cmd,&ncmd[cmd_index].nseq,YAESU_CMD_LENGTH);  
+  /* change opcode according to vfo */
+  n = opcode_vfo(rig, p_cmd, cmd_index, vfo);
+  if (n != RIG_OK)
+	  return n;
 
-  cmd = p->p_cmd;
-  write_block(&rs->rigport, (char *) cmd, YAESU_CMD_LENGTH);
+  n = write_block(&rs->rigport, (char *) p_cmd, YAESU_CMD_LENGTH);
+  if (n < 0)
+    return n;
 
   n = read_block(&rs->rigport, (char *) data, YAESU_CMD_LENGTH);
   if (n != YAESU_CMD_LENGTH) {
@@ -550,28 +560,28 @@ static int get_freq_and_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
   case MD_USB: *mode = RIG_MODE_USB; break;
 
   case MD_CWN: 
-			   *width = rig_passband_narrow(rig, RIG_MODE_CW);
+		*width = rig_passband_narrow(rig, RIG_MODE_CW);
   case MD_CW:  
-			   *mode = RIG_MODE_CW;
-			   break;
+		*mode = RIG_MODE_CW;
+		break;
 
   case MD_CWNR:
-			   *width = rig_passband_narrow(rig, RIG_MODE_CW);
+		*width = rig_passband_narrow(rig, RIG_MODE_CW);
   case MD_CWR: 
-				*mode = RIG_MODE_CWR;
-				break;
+		*mode = RIG_MODE_CWR;
+		break;
 
   case MD_AMN:
-			   *width = rig_passband_narrow(rig, RIG_MODE_AM);
+		*width = rig_passband_narrow(rig, RIG_MODE_AM);
   case MD_AM:
-			   *mode = RIG_MODE_AM;
-			   break;
+		*mode = RIG_MODE_AM;
+		break;
 
   case MD_FMN:
-			   *width = rig_passband_narrow(rig, RIG_MODE_FM);
+		*width = rig_passband_narrow(rig, RIG_MODE_FM);
   case MD_FM:  
-			   *mode = RIG_MODE_FM; 
-			   break;
+		*mode = RIG_MODE_FM; 
+		break;
   default:
     *mode = RIG_MODE_NONE;
     rig_debug(RIG_DEBUG_VERBOSE,"ft847: Unknown mode %02x\n", data[4]);
@@ -600,15 +610,13 @@ int ft847_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 
 
-/*
- * TODO -- add other VFO's
- *
- */
-
 int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
   unsigned char cmd_index;	/* index of sequence to send */
   struct rig_state *rs = &rig->state;
   struct ft847_priv_data *p;
+  unsigned char p_cmd[YAESU_CMD_LENGTH]; /* sequence to send */
+  int ret;
+
 
   p = (struct ft847_priv_data*)rs->priv;
 
@@ -619,14 +627,6 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
 
   rig_debug(RIG_DEBUG_VERBOSE,"ft847: generic mode = %x \n", mode);
 
-  if (vfo == RIG_VFO_CURR)
-	vfo = p->current_vfo;
-
-  if (vfo != RIG_VFO_MAIN) {
-    rig_debug(RIG_DEBUG_VERBOSE,"ft847: unsupported VFO '%s'\n", rig_strvfo(vfo));
-    return -RIG_ENIMPL;		/* sorry, it's in TODO list */
-  }
-
 
   switch(mode) {
   case RIG_MODE_AM:
@@ -635,6 +635,9 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
   case RIG_MODE_CW:
     cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_CW;
     break;
+  case RIG_MODE_CWR:
+    cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_CWR;
+    break;
   case RIG_MODE_USB:
     cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_USB;
     break;
@@ -664,6 +667,9 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
     case RIG_MODE_CW:
       cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_CWN;
       break;
+    case RIG_MODE_CWR:
+      cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_CWRN;
+      break;
     case RIG_MODE_USB:
     case RIG_MODE_LSB:
       break;
@@ -682,10 +688,11 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
   /*
    * Now send the command
    */
+  ret = opcode_vfo(rig, p_cmd, cmd_index, vfo);
+  if (ret != RIG_OK)
+	  return ret;
 
-  ft847_send_priv_cmd(rig,cmd_index);
-
-  return RIG_OK;
+  return write_block(&rs->rigport, (char*)p_cmd, YAESU_CMD_LENGTH);
 }
 
 int ft847_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width) {
@@ -696,61 +703,65 @@ int ft847_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width) {
 
 
 /*
- * TODO -- FT847 has NO set_vfo cmd. VFO is specified
- * in other cmd's like set freq, set mode etc..
- *
- * For the time being, simply cache the requested
- * VFO in private active VFO
- * Must fix this later. MAybe store active VFO in
- * frontend instead ?
- *
- * Perhaps I can try a dummy cmd that includes the VFO..
- * eg: set_dcs etc..
- * Try later -- FS
- *
- *
- * Also, RIG can handle only VFO_MAIN . Add SAT VFO's later.
- *
+ * Not exactly Split mode, this will set *SAT* Mode
  */
+int ft847_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
+{
+  struct ft847_priv_data *priv = (struct ft847_priv_data*)rig->state.priv;
+  unsigned char cmd_index;	/* index of sequence to send */
+  int ret;
 
-int ft847_set_vfo(RIG *rig, vfo_t vfo) {
-  struct rig_state *rig_s;
-  struct ft847_priv_data *p;
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called\n", __func__);
 
-  if (!rig)
-    return -RIG_EINVAL;
-  
-  p = (struct ft847_priv_data*)rig->state.priv;
-  rig_s = &rig->state;
-  
-  
-  /* 
-   * TODO : check for errors -- FS
-   */
-
-  switch(vfo) {
-  case RIG_VFO_CURR:
-	  return 0;		/* easy! */
-
-  case RIG_VFO_MAIN:
-    p->current_vfo = vfo;		/* update active VFO */
+  switch(split) {
+  case RIG_SPLIT_ON:
+    cmd_index = FT_847_NATIVE_CAT_SAT_MODE_ON;
+    break;
+  case RIG_SPLIT_OFF:
+    cmd_index = FT_847_NATIVE_CAT_SAT_MODE_OFF;
     break;
   default:
-    return -RIG_EINVAL;		/* sorry, wrong VFO */
+    return -RIG_EINVAL;		/* sorry, wrong split range */
   }
 
+  ret = ft847_send_priv_cmd(rig,cmd_index);
+  if (ret == RIG_OK)
+	  priv->sat_mode = split;
 
+  return ret;
+}
+
+int ft847_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
+{
+  struct ft847_priv_data *priv = (struct ft847_priv_data*)rig->state.priv;
+
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called\n", __func__);
+
+  *split = priv->sat_mode;
+  *tx_vfo = RIG_VFO_SUB;
 
   return RIG_OK;
-
 }
 
-int ft847_get_vfo(RIG *rig, vfo_t *vfo) {
-
-  return -RIG_ENIMPL;
-
+int ft847_set_split_freq(RIG *rig, vfo_t vfo, freq_t freq)
+{
+	return ft847_set_freq(rig, RIG_VFO_TX, freq);
 }
 
+int ft847_get_split_freq(RIG *rig, vfo_t vfo, freq_t *freq)
+{
+	return ft847_get_freq(rig, RIG_VFO_TX, freq);
+}
+
+int ft847_set_split_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
+{
+	return ft847_set_mode(rig, RIG_VFO_TX, mode, width);
+}
+
+int ft847_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
+{
+	return ft847_get_mode(rig, RIG_VFO_TX, mode, width);
+}
 
 /*
  * _set_ptt
@@ -778,14 +789,176 @@ int ft847_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt) {
    * phew! now send cmd to rig
    */ 
 
-  ft847_send_priv_cmd(rig,cmd_index);
+  return ft847_send_priv_cmd(rig,cmd_index);
 
-  return RIG_OK;		/* good */
+}
 
+static int ft847_get_status(RIG *rig, int status_ci)
+{
+  struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+  unsigned char *data;
+  int len;
+  int n;
+
+  switch (status_ci) {
+  case FT_847_NATIVE_CAT_GET_RX_STATUS:
+    data = &p->rx_status;
+    len  = 1;
+    break;
+  case FT_847_NATIVE_CAT_GET_TX_STATUS:
+    data = &p->tx_status;
+    len  = 1;
+    break;
+  default:
+    rig_debug(RIG_DEBUG_ERR, "ft847_get_status: Internal error!\n");
+    return -RIG_EINTERNAL;
+  }
+
+  serial_flush(&rig->state.rigport);
+
+  n = write_block(&rig->state.rigport, (char *) ncmd[status_ci].nseq, YAESU_CMD_LENGTH);
+  if (n < 0)
+    return n;
+
+  n = read_block(&rig->state.rigport, (char *) data, len);
+  if (n < 0)
+    return n;
+
+  if (n != len)
+    return -RIG_EPROTO;
+
+  return RIG_OK;
 }
 
 int ft847_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt) {
-  return -RIG_ENIMPL;
+
+  struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+  int n;
+
+
+  n = ft847_get_status(rig, FT_847_NATIVE_CAT_GET_TX_STATUS);
+  if (n < 0)
+    return n;
+
+  *ptt = (p->tx_status & 0x80) ? RIG_PTT_OFF : RIG_PTT_ON;
+
+  return RIG_OK;
+}
+
+
+int ft847_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd) {
+
+  struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+  int n;
+
+
+  n = ft847_get_status(rig, FT_847_NATIVE_CAT_GET_RX_STATUS);
+  if (n < 0)
+    return n;
+
+  *dcd = (p->rx_status & 0x80) ? RIG_DCD_OFF : RIG_DCD_ON;
+
+  return RIG_OK;
+}
+
+
+
+/*
+ * Get the 'raw' signal strength
+ * This number corresponds to the number of 'dots' in
+ * the FT-847 display
+ */
+static int ft847_get_rawstr_level(RIG *rig, value_t *val)
+{
+  struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+  int n;
+
+
+  n = ft847_get_status(rig, FT_847_NATIVE_CAT_GET_RX_STATUS);
+  if (n < 0)
+    return n;
+
+  n = (p->rx_status & 0x1F);
+
+  val->i = n;
+
+  return RIG_OK;
+}
+
+
+/*
+ * Get S-meter reading (in dB)
+*/
+static int ft847_get_smeter_level(RIG *rig, value_t *val)
+{
+  int n;
+
+  n = ft847_get_rawstr_level(rig, val);
+  if (n < 0)
+    return n;
+
+  /* 
+   * The FT-847 S-meter readings over CAT returns
+   * an integer that corresponds to the number of
+   * 'dots' lit in the display. Use a conversion
+   * function to convert the raw signal strength to dB 
+   */
+  n = val->i;
+  if (n < 4)  /* <= S1 */
+    val->i = -54 + (n * 2);
+  else if (n < 20) /* S1 - S9 */
+    val->i = -48 + ((n -3) * 3);
+  else { /* > S9 */
+    n -= 19;
+    val->i = (n * 5);
+  }
+  
+  return RIG_OK;
+}
+
+/*
+ * Get the PO/ALC Meter Data
+ */
+static int ft847_get_alc_level(RIG *rig, value_t *val)
+{
+  struct ft847_priv_data *p = (struct ft847_priv_data *) rig->state.priv;
+  int n;
+
+  n = ft847_get_status(rig, FT_847_NATIVE_CAT_GET_TX_STATUS);
+  if (n < 0)
+    return n;
+
+  n = (p->tx_status & 0x1F);
+
+  val->f = (float)n / 0x1F;
+
+  return RIG_OK;
+}
+
+
+/*
+ * Get "level" data from rig.
+ * The 847 supports S-meter readings in receive mode
+ * and PO/ALC in transmit mode.  There is no way
+ * to determine whether it's PO or ALC, unfortunately.
+ */
+int ft847_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t * val) 
+{
+  if (vfo != RIG_VFO_CURR)
+    return -RIG_ENTARGET;
+
+  switch (level) {
+  case RIG_LEVEL_STRENGTH:
+    return ft847_get_smeter_level(rig, val);
+  case RIG_LEVEL_RAWSTR:
+    return ft847_get_rawstr_level(rig, val);
+  case RIG_LEVEL_ALC:
+    return ft847_get_alc_level(rig, val);
+  default:
+    return -RIG_EINVAL;
+  }
+
+  return RIG_OK;
 
 }
 
