@@ -3,6 +3,7 @@
  *              and the Hamlib Group (hamlib-developer at lists.sourceforge.net)
  *
  * newcat.h - (C) Nate Bargmann 2007 (n0nb at arrl.net)
+ *            (C) Terry Embry 2008
  *
  * This shared library provides the backend API for communicating
  * via serial interface to any Yaesu radio using the new "CAT"
@@ -12,7 +13,7 @@
  * FT-950, FT-450.  Much testing remains.  -N0NB
  *
  *
- *    $Id: newcat.h,v 1.6 2008/11/01 22:39:07 fillods Exp $
+ *    $Id: newcat.h,v 1.20 2009/01/04 14:01:02 mrtembry Exp $
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -35,6 +36,7 @@
 #ifndef _NEWCAT_H
 #define _NEWCAT_H 1
 
+#include <tones.h>
 
 /* Handy constants */
 
@@ -50,7 +52,7 @@
 typedef char ncboolean;
 
 /* shared function version */
-#define NEWCAT_VER "0.2"
+#define NEWCAT_VER "0.21"
 
 /* Hopefully large enough for future use, 128 chars plus '\0' */
 #define NEWCAT_DATA_LEN                 129
@@ -62,13 +64,11 @@ typedef char ncboolean;
 #define NEWCAT_MEM_CAP {    \
 	.freq = 1,      \
 	.mode = 1,      \
-	.width = 1,     \
 	.rit = 1,       \
 	.xit = 1,       \
-	.rptr_offs = 1, \
+	.rptr_shift = 1, \
 	.ctcss_tone = 1,\
 	.ctcss_sql = 1,\
-	.funcs = (RIG_FUNC_TONE|RIG_FUNC_TSQL), \
 }
 
 /*
@@ -81,7 +81,15 @@ typedef char ncboolean;
  *      newcat_get_freq
  *      newcat_set_vfo
  *      newcat_get_vfo
- *
+ *      newcat_get_rit
+ *      newcat_set_rit
+ *      newcat_get_xit
+ *      newcat_set_xit
+ *      power2mW
+ *      mW2power
+ *      newcat_get_ant
+ *      newcat_set_ant
+ *      newcat_get_ptt
  * Functions not yet implemented
  * most everything at this time.
  *
@@ -113,6 +121,9 @@ int newcat_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
 int newcat_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
 
 int newcat_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
+int newcat_get_ptt(RIG * rig, vfo_t vfo, ptt_t * ptt);
+int newcat_set_ant(RIG * rig, vfo_t vfo, ant_t ant);
+int newcat_get_ant(RIG * rig, vfo_t vfo, ant_t * ant);
 int newcat_set_level(RIG * rig, vfo_t vfo, setting_t level, value_t val);
 int newcat_get_level(RIG * rig, vfo_t vfo, setting_t level, value_t * val);
 int newcat_set_func(RIG * rig, vfo_t vfo, setting_t func, int status);
@@ -122,5 +133,27 @@ int newcat_get_mem(RIG * rig, vfo_t vfo, int *ch);
 int newcat_vfo_op(RIG * rig, vfo_t vfo, vfo_op_t op);
 const char *newcat_get_info(RIG * rig);
 
+int newcat_get_rit(RIG * rig, vfo_t vfo, shortfreq_t * rit);
+int newcat_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit);
+int newcat_get_xit(RIG * rig, vfo_t vfo, shortfreq_t * xit);
+int newcat_set_xit(RIG * rig, vfo_t vfo, shortfreq_t xit);
+int newcat_power2mW(RIG * rig, unsigned int *mwpower, float power, freq_t freq, rmode_t mode);
+int newcat_mW2power(RIG * rig, float *power, unsigned int mwpower, freq_t freq, rmode_t mode);
+int newcat_set_split_vfo(RIG * rig, vfo_t vfo, split_t split, vfo_t tx_vfo);
+int newcat_get_split_vfo(RIG * rig, vfo_t vfo, split_t * split, vfo_t *tx_vfo);
+int newcat_set_rptr_shift(RIG * rig, vfo_t vfo, rptr_shift_t rptr_shift);
+int newcat_get_rptr_shift(RIG * rig, vfo_t vfo, rptr_shift_t * rptr_shift);
+int newcat_set_ctcss_tone(RIG * rig, vfo_t vfo, tone_t tone);
+int newcat_get_ctcss_tone(RIG * rig, vfo_t vfo, tone_t * tone);
+int newcat_set_ctcss_sql(RIG * rig, vfo_t vfo, tone_t tone);
+int newcat_get_ctcss_sql(RIG * rig, vfo_t vfo, tone_t * tone);
+int newcat_set_powerstat(RIG * rig, powerstat_t status);
+int newcat_get_powerstat(RIG * rig, powerstat_t * status);
+int newcat_set_ts(RIG * rig, vfo_t vfo, shortfreq_t ts);
+int newcat_get_ts(RIG * rig, vfo_t vfo, shortfreq_t * ts);
+int newcat_set_trn(RIG * rig, int trn);
+int newcat_get_trn(RIG * rig, int *trn);
+int newcat_set_channel(RIG * rig, const channel_t * chan);
+int newcat_get_channel(RIG * rig, channel_t * chan);
 
 #endif /* _NEWCAT_H */
